// Generated by the protocol buffer compiler.  DO NOT EDIT!
// NO CHECKED-IN PROTOBUF GENCODE
// source: google/cloud/bigquery/storage/v1/stream.proto
// Protobuf C++ Version: 7.35.1

#include "google/cloud/bigquery/storage/v1/stream.pb.h"

#include <algorithm>
#include <type_traits>
#include "google/protobuf/io/coded_stream.h"
#include "google/protobuf/generated_message_tctable_impl.h"
#include "google/protobuf/internal_visibility.h"
#include "google/protobuf/extension_set.h"
#include "google/protobuf/generated_message_util.h"
#include "google/protobuf/wire_format_lite.h"
#include "google/protobuf/descriptor.h"
#include "google/protobuf/generated_message_reflection.h"
#include "google/protobuf/reflection_ops.h"
#include "google/protobuf/wire_format.h"
// @@protoc_insertion_point(includes)

// Must be included last.
#include "google/protobuf/port_def.inc"
PROTOBUF_PRAGMA_INIT_SEG
namespace _pb = ::google::protobuf;
namespace _pbi = ::google::protobuf::internal;
namespace _fl = ::google::protobuf::internal::field_layout;
#ifdef PROTOBUF_MESSAGE_GLOBALS
namespace {
PROTOBUF_CONSTINIT ::google::protobuf::internal::ReflectionData
    file_reflection_data[] = {
        // ::google::cloud::bigquery::storage::v1::ReadSession_TableModifiers
        {&::_pbi::kDescriptorMethods, &::descriptor_table_google_2fcloud_2fbigquery_2fstorage_2fv1_2fstream_2eproto, /* tracker*/ nullptr,},
        // ::google::cloud::bigquery::storage::v1::ReadSession_TableReadOptions
        {&::_pbi::kDescriptorMethods, &::descriptor_table_google_2fcloud_2fbigquery_2fstorage_2fv1_2fstream_2eproto, /* tracker*/ nullptr,},
        // ::google::cloud::bigquery::storage::v1::ReadSession
        {&::_pbi::kDescriptorMethods, &::descriptor_table_google_2fcloud_2fbigquery_2fstorage_2fv1_2fstream_2eproto, /* tracker*/ nullptr,},
        // ::google::cloud::bigquery::storage::v1::ReadStream
        {&::_pbi::kDescriptorMethods, &::descriptor_table_google_2fcloud_2fbigquery_2fstorage_2fv1_2fstream_2eproto, /* tracker*/ nullptr,},
        // ::google::cloud::bigquery::storage::v1::WriteStream
        {&::_pbi::kDescriptorMethods, &::descriptor_table_google_2fcloud_2fbigquery_2fstorage_2fv1_2fstream_2eproto, /* tracker*/ nullptr,},
};
}  // namespace
#endif
namespace google {
namespace cloud {
namespace bigquery {
namespace storage {
namespace v1 {
class ReadStream::_Internal {
 public:
  using HasBits = decltype(::std::declval<ReadStream>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(ReadStream, _impl_._has_bits_);
};

constexpr ReadStream::ParseTableT_ ReadStream::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(ReadStream, _impl_._has_bits_),
      0, // no _extensions_
      1, 0,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967294,  // skipmap
      offsetof(ParseTableT_, field_entries),
      1,  // num_field_entries
      0,  // num_aux_entries
      offsetof(ParseTableT_, field_names),  // no aux_entries
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::google::cloud::bigquery::storage::v1::ReadStream>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // string name = 1 [(.google.api.field_behavior) = OUTPUT_ONLY];
      {::_pbi::TcParser::FastUS1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(ReadStream, _impl_.name_)}},
    }}, {{
      65535, 65535
    }}, {{
      // string name = 1 [(.google.api.field_behavior) = OUTPUT_ONLY];
      {PROTOBUF_FIELD_OFFSET(ReadStream, _impl_.name_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    }},
    // no aux_entries
    {{
      "\53\4\0\0\0\0\0\0"
      "google.cloud.bigquery.storage.v1.ReadStream"
      "name"
    }},
  };
}


inline constexpr ReadStream::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        name_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()) {}

template <typename>
constexpr ReadStream::ReadStream(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL ReadStream::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) ReadStream(arena);
}
constexpr auto ReadStream::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(ReadStream), alignof(ReadStream));
}
constexpr auto ReadStream::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &ReadStream::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<ReadStream>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &ReadStream::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<ReadStream>(), &ReadStream::ByteSizeLong,
              &ReadStream::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(ReadStream, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[3],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_google_2fcloud_2fbigquery_2fstorage_2fv1_2fstream_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct ReadStreamGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr ReadStreamGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 ReadStream_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(ReadStream::InternalGenerateClassData_(
            _default, &ReadStream_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<ReadStream>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~ReadStreamGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) ReadStream _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<ReadStream>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(ReadStreamGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST ReadStreamGlobalsTypeInternal ReadStream_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* ReadStream_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return ReadStream_globals_.GetClassData();
#else
  return ReadStream_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class ReadSession_TableReadOptions::_Internal {
 public:
  using HasBits = decltype(::std::declval<ReadSession_TableReadOptions>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(ReadSession_TableReadOptions, _impl_._has_bits_);
  static constexpr ::int32_t kOneofCaseOffset =
      PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ReadSession_TableReadOptions, _impl_._oneof_case_);
};

constexpr ReadSession_TableReadOptions::ParseTableT_ ReadSession_TableReadOptions::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(ReadSession_TableReadOptions, _impl_._has_bits_),
      0, // no _extensions_
      5, 56,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967264,  // skipmap
      offsetof(ParseTableT_, field_entries),
      5,  // num_field_entries
      2,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::google::cloud::bigquery::storage::v1::ReadSession_TableReadOptions>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      {::_pbi::TcParser::MiniParse, {}},
      // repeated string selected_fields = 1;
      {::_pbi::TcParser::FastUR1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(ReadSession_TableReadOptions, _impl_.selected_fields_)}},
      // string row_restriction = 2;
      {::_pbi::TcParser::FastUS1,
       {18, 1, 0,
        PROTOBUF_FIELD_OFFSET(ReadSession_TableReadOptions, _impl_.row_restriction_)}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
      // optional double sample_percentage = 5 [(.google.api.field_behavior) = OPTIONAL];
      {::_pbi::TcParser::FastF64S1,
       {41, 2, 0,
        PROTOBUF_FIELD_OFFSET(ReadSession_TableReadOptions, _impl_.sample_percentage_)}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
    }}, {{
      65535, 65535
    }}, {{
      // repeated string selected_fields = 1;
      {PROTOBUF_FIELD_OFFSET(ReadSession_TableReadOptions, _impl_.selected_fields_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcRepeated | ::_fl::kUtf8String | ::_fl::kRepSString)},
      // string row_restriction = 2;
      {PROTOBUF_FIELD_OFFSET(ReadSession_TableReadOptions, _impl_.row_restriction_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // .google.cloud.bigquery.storage.v1.ArrowSerializationOptions arrow_serialization_options = 3 [(.google.api.field_behavior) = OPTIONAL];
      {PROTOBUF_FIELD_OFFSET(ReadSession_TableReadOptions, _impl_.output_format_serialization_options_.arrow_serialization_options_), _Internal::kOneofCaseOffset + 0, 0, (0 | ::_fl::kFcOneof | ::_fl::kMessage | ::_fl::kTvTable)},
      // .google.cloud.bigquery.storage.v1.AvroSerializationOptions avro_serialization_options = 4 [(.google.api.field_behavior) = OPTIONAL];
      {PROTOBUF_FIELD_OFFSET(ReadSession_TableReadOptions, _impl_.output_format_serialization_options_.avro_serialization_options_), _Internal::kOneofCaseOffset + 0, 1, (0 | ::_fl::kFcOneof | ::_fl::kMessage | ::_fl::kTvTable)},
      // optional double sample_percentage = 5 [(.google.api.field_behavior) = OPTIONAL];
      {PROTOBUF_FIELD_OFFSET(ReadSession_TableReadOptions, _impl_.sample_percentage_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kDouble)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::google::cloud::bigquery::storage::v1::ArrowSerializationOptions>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::google::cloud::bigquery::storage::v1::ArrowSerializationOptions_globals_},
        #endif
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::google::cloud::bigquery::storage::v1::AvroSerializationOptions>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::google::cloud::bigquery::storage::v1::AvroSerializationOptions_globals_},
        #endif
    }},
    {{
      "\75\17\17\0\0\0\0\0"
      "google.cloud.bigquery.storage.v1.ReadSession.TableReadOptions"
      "selected_fields"
      "row_restriction"
    }},
  };
}


inline constexpr ReadSession_TableReadOptions::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        selected_fields_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::google::cloud::bigquery::storage::v1::ReadSession_TableReadOptions,
            PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ReadSession_TableReadOptions, _impl_.selected_fields_)>()
         }
        ,
        row_restriction_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        sample_percentage_{0},
        output_format_serialization_options_{},
        _oneof_case_{} {}

template <typename>
constexpr ReadSession_TableReadOptions::ReadSession_TableReadOptions(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL ReadSession_TableReadOptions::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) ReadSession_TableReadOptions(arena);
}
constexpr auto ReadSession_TableReadOptions::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(ReadSession_TableReadOptions), alignof(ReadSession_TableReadOptions));
}
constexpr auto ReadSession_TableReadOptions::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &ReadSession_TableReadOptions::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<ReadSession_TableReadOptions>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &ReadSession_TableReadOptions::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<ReadSession_TableReadOptions>(), &ReadSession_TableReadOptions::ByteSizeLong,
              &ReadSession_TableReadOptions::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(ReadSession_TableReadOptions, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[1],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_google_2fcloud_2fbigquery_2fstorage_2fv1_2fstream_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct ReadSession_TableReadOptionsGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr ReadSession_TableReadOptionsGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 ReadSession_TableReadOptions_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(ReadSession_TableReadOptions::InternalGenerateClassData_(
            _default, &ReadSession_TableReadOptions_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<ReadSession_TableReadOptions>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~ReadSession_TableReadOptionsGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) ReadSession_TableReadOptions _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<ReadSession_TableReadOptions>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(ReadSession_TableReadOptionsGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST ReadSession_TableReadOptionsGlobalsTypeInternal ReadSession_TableReadOptions_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* ReadSession_TableReadOptions_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return ReadSession_TableReadOptions_globals_.GetClassData();
#else
  return ReadSession_TableReadOptions_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class ReadSession_TableModifiers::_Internal {
 public:
  using HasBits = decltype(::std::declval<ReadSession_TableModifiers>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(ReadSession_TableModifiers, _impl_._has_bits_);
};

constexpr ReadSession_TableModifiers::ParseTableT_ ReadSession_TableModifiers::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(ReadSession_TableModifiers, _impl_._has_bits_),
      0, // no _extensions_
      1, 0,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967294,  // skipmap
      offsetof(ParseTableT_, field_entries),
      1,  // num_field_entries
      1,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::google::cloud::bigquery::storage::v1::ReadSession_TableModifiers>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // .google.protobuf.Timestamp snapshot_time = 1;
      {::_pbi::TcParser::FastMtS1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(ReadSession_TableModifiers, _impl_.snapshot_time_)}},
    }}, {{
      65535, 65535
    }}, {{
      // .google.protobuf.Timestamp snapshot_time = 1;
      {PROTOBUF_FIELD_OFFSET(ReadSession_TableModifiers, _impl_.snapshot_time_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::google::protobuf::Timestamp>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::google::protobuf::Timestamp_globals_},
        #endif
    }},
    {{
    }},
  };
}


inline constexpr ReadSession_TableModifiers::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        snapshot_time_{nullptr} {}

template <typename>
constexpr ReadSession_TableModifiers::ReadSession_TableModifiers(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL ReadSession_TableModifiers::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) ReadSession_TableModifiers(arena);
}
constexpr auto ReadSession_TableModifiers::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::ZeroInit(sizeof(ReadSession_TableModifiers), alignof(ReadSession_TableModifiers));
}
constexpr auto ReadSession_TableModifiers::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &ReadSession_TableModifiers::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<ReadSession_TableModifiers>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &ReadSession_TableModifiers::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<ReadSession_TableModifiers>(), &ReadSession_TableModifiers::ByteSizeLong,
              &ReadSession_TableModifiers::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(ReadSession_TableModifiers, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[0],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_google_2fcloud_2fbigquery_2fstorage_2fv1_2fstream_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct ReadSession_TableModifiersGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr ReadSession_TableModifiersGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 ReadSession_TableModifiers_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(ReadSession_TableModifiers::InternalGenerateClassData_(
            _default, &ReadSession_TableModifiers_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<ReadSession_TableModifiers>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~ReadSession_TableModifiersGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) ReadSession_TableModifiers _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<ReadSession_TableModifiers>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(ReadSession_TableModifiersGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST ReadSession_TableModifiersGlobalsTypeInternal ReadSession_TableModifiers_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* ReadSession_TableModifiers_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return ReadSession_TableModifiers_globals_.GetClassData();
#else
  return ReadSession_TableModifiers_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class WriteStream::_Internal {
 public:
  using HasBits = decltype(::std::declval<WriteStream>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(WriteStream, _impl_._has_bits_);
};

constexpr WriteStream::ParseTableT_ WriteStream::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(WriteStream, _impl_._has_bits_),
      0, // no _extensions_
      8, 56,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294967072,  // skipmap
      offsetof(ParseTableT_, field_entries),
      7,  // num_field_entries
      3,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::google::cloud::bigquery::storage::v1::WriteStream>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      // string location = 8 [(.google.api.field_behavior) = IMMUTABLE];
      {::_pbi::TcParser::FastUS1,
       {66, 1, 0,
        PROTOBUF_FIELD_OFFSET(WriteStream, _impl_.location_)}},
      // string name = 1 [(.google.api.field_behavior) = OUTPUT_ONLY];
      {::_pbi::TcParser::FastUS1,
       {10, 0, 0,
        PROTOBUF_FIELD_OFFSET(WriteStream, _impl_.name_)}},
      // .google.cloud.bigquery.storage.v1.WriteStream.Type type = 2 [(.google.api.field_behavior) = IMMUTABLE];
      {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(WriteStream, _impl_.type_), 5>(),
       {16, 5, 0,
        PROTOBUF_FIELD_OFFSET(WriteStream, _impl_.type_)}},
      // .google.protobuf.Timestamp create_time = 3 [(.google.api.field_behavior) = OUTPUT_ONLY];
      {::_pbi::TcParser::FastMtS1,
       {26, 2, 0,
        PROTOBUF_FIELD_OFFSET(WriteStream, _impl_.create_time_)}},
      // .google.protobuf.Timestamp commit_time = 4 [(.google.api.field_behavior) = OUTPUT_ONLY];
      {::_pbi::TcParser::FastMtS1,
       {34, 3, 1,
        PROTOBUF_FIELD_OFFSET(WriteStream, _impl_.commit_time_)}},
      // .google.cloud.bigquery.storage.v1.TableSchema table_schema = 5 [(.google.api.field_behavior) = OUTPUT_ONLY];
      {::_pbi::TcParser::FastMtS1,
       {42, 4, 2,
        PROTOBUF_FIELD_OFFSET(WriteStream, _impl_.table_schema_)}},
      {::_pbi::TcParser::MiniParse, {}},
      // .google.cloud.bigquery.storage.v1.WriteStream.WriteMode write_mode = 7 [(.google.api.field_behavior) = IMMUTABLE];
      {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(WriteStream, _impl_.write_mode_), 6>(),
       {56, 6, 0,
        PROTOBUF_FIELD_OFFSET(WriteStream, _impl_.write_mode_)}},
    }}, {{
      65535, 65535
    }}, {{
      // string name = 1 [(.google.api.field_behavior) = OUTPUT_ONLY];
      {PROTOBUF_FIELD_OFFSET(WriteStream, _impl_.name_), _Internal::kHasBitsOffset + 0, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // .google.cloud.bigquery.storage.v1.WriteStream.Type type = 2 [(.google.api.field_behavior) = IMMUTABLE];
      {PROTOBUF_FIELD_OFFSET(WriteStream, _impl_.type_), _Internal::kHasBitsOffset + 5, 0, (0 | ::_fl::kFcOptional | ::_fl::kOpenEnum)},
      // .google.protobuf.Timestamp create_time = 3 [(.google.api.field_behavior) = OUTPUT_ONLY];
      {PROTOBUF_FIELD_OFFSET(WriteStream, _impl_.create_time_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
      // .google.protobuf.Timestamp commit_time = 4 [(.google.api.field_behavior) = OUTPUT_ONLY];
      {PROTOBUF_FIELD_OFFSET(WriteStream, _impl_.commit_time_), _Internal::kHasBitsOffset + 3, 1, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
      // .google.cloud.bigquery.storage.v1.TableSchema table_schema = 5 [(.google.api.field_behavior) = OUTPUT_ONLY];
      {PROTOBUF_FIELD_OFFSET(WriteStream, _impl_.table_schema_), _Internal::kHasBitsOffset + 4, 2, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
      // .google.cloud.bigquery.storage.v1.WriteStream.WriteMode write_mode = 7 [(.google.api.field_behavior) = IMMUTABLE];
      {PROTOBUF_FIELD_OFFSET(WriteStream, _impl_.write_mode_), _Internal::kHasBitsOffset + 6, 0, (0 | ::_fl::kFcOptional | ::_fl::kOpenEnum)},
      // string location = 8 [(.google.api.field_behavior) = IMMUTABLE];
      {PROTOBUF_FIELD_OFFSET(WriteStream, _impl_.location_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::google::protobuf::Timestamp>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::google::protobuf::Timestamp_globals_},
        #endif
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::google::protobuf::Timestamp>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::google::protobuf::Timestamp_globals_},
        #endif
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::google::cloud::bigquery::storage::v1::TableSchema>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::google::cloud::bigquery::storage::v1::TableSchema_globals_},
        #endif
    }},
    {{
      "\54\4\0\0\0\0\0\10"
      "google.cloud.bigquery.storage.v1.WriteStream"
      "name"
      "location"
    }},
  };
}


inline constexpr WriteStream::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        name_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        location_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        create_time_{nullptr},
        commit_time_{nullptr},
        table_schema_{nullptr},
        type_{static_cast< ::google::cloud::bigquery::storage::v1::WriteStream_Type >(0)},
        write_mode_{static_cast< ::google::cloud::bigquery::storage::v1::WriteStream_WriteMode >(0)} {}

template <typename>
constexpr WriteStream::WriteStream(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL WriteStream::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) WriteStream(arena);
}
constexpr auto WriteStream::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(WriteStream), alignof(WriteStream));
}
constexpr auto WriteStream::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &WriteStream::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<WriteStream>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &WriteStream::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<WriteStream>(), &WriteStream::ByteSizeLong,
              &WriteStream::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(WriteStream, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[4],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_google_2fcloud_2fbigquery_2fstorage_2fv1_2fstream_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct WriteStreamGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr WriteStreamGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 WriteStream_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(WriteStream::InternalGenerateClassData_(
            _default, &WriteStream_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<WriteStream>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~WriteStreamGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) WriteStream _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<WriteStream>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(WriteStreamGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST WriteStreamGlobalsTypeInternal WriteStream_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* WriteStream_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return WriteStream_globals_.GetClassData();
#else
  return WriteStream_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
class ReadSession::_Internal {
 public:
  using HasBits = decltype(::std::declval<ReadSession>()._impl_._has_bits_);
  static constexpr ::int32_t kHasBitsOffset =
      8 * PROTOBUF_FIELD_OFFSET(ReadSession, _impl_._has_bits_);
  static constexpr ::int32_t kOneofCaseOffset =
      PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ReadSession, _impl_._oneof_case_);
};

constexpr ReadSession::ParseTableT_ ReadSession::InternalGenerateParseTable_(const ::_pbi::ClassData* class_data) {
  return ParseTableT_{
    {
      PROTOBUF_FIELD_OFFSET(ReadSession, _impl_._has_bits_),
      0, // no _extensions_
      14, 120,  // max_field_number, fast_idx_mask
      offsetof(ParseTableT_, field_lookup_table),
      4294952192,  // skipmap
      offsetof(ParseTableT_, field_entries),
      12,  // num_field_entries
      6,  // num_aux_entries
      offsetof(ParseTableT_, aux_entries),
      class_data,
      nullptr,  // post_loop_handler
      ::_pbi::TcParser::GenericFallback,  // fallback
      #ifdef PROTOBUF_PREFETCH_PARSE_TABLE
      ::_pbi::TcParser::GetTable<::google::cloud::bigquery::storage::v1::ReadSession>(),  // to_prefetch
      #endif  // PROTOBUF_PREFETCH_PARSE_TABLE
    }, {{
      {::_pbi::TcParser::MiniParse, {}},
      // string name = 1 [(.google.api.field_behavior) = OUTPUT_ONLY];
      {::_pbi::TcParser::FastUS1,
       {10, 1, 0,
        PROTOBUF_FIELD_OFFSET(ReadSession, _impl_.name_)}},
      // .google.protobuf.Timestamp expire_time = 2 [(.google.api.field_behavior) = OUTPUT_ONLY];
      {::_pbi::TcParser::FastMtS1,
       {18, 4, 0,
        PROTOBUF_FIELD_OFFSET(ReadSession, _impl_.expire_time_)}},
      // .google.cloud.bigquery.storage.v1.DataFormat data_format = 3 [(.google.api.field_behavior) = IMMUTABLE];
      {::_pbi::TcParser::SingularVarintNoZag1<::uint32_t, offsetof(ReadSession, _impl_.data_format_), 9>(),
       {24, 9, 0,
        PROTOBUF_FIELD_OFFSET(ReadSession, _impl_.data_format_)}},
      {::_pbi::TcParser::MiniParse, {}},
      {::_pbi::TcParser::MiniParse, {}},
      // string table = 6 [(.google.api.field_behavior) = IMMUTABLE, (.google.api.resource_reference) = {
      {::_pbi::TcParser::FastUS1,
       {50, 2, 0,
        PROTOBUF_FIELD_OFFSET(ReadSession, _impl_.table_)}},
      // .google.cloud.bigquery.storage.v1.ReadSession.TableModifiers table_modifiers = 7 [(.google.api.field_behavior) = OPTIONAL];
      {::_pbi::TcParser::FastMtS1,
       {58, 5, 3,
        PROTOBUF_FIELD_OFFSET(ReadSession, _impl_.table_modifiers_)}},
      // .google.cloud.bigquery.storage.v1.ReadSession.TableReadOptions read_options = 8 [(.google.api.field_behavior) = OPTIONAL];
      {::_pbi::TcParser::FastMtS1,
       {66, 6, 4,
        PROTOBUF_FIELD_OFFSET(ReadSession, _impl_.read_options_)}},
      {::_pbi::TcParser::MiniParse, {}},
      // repeated .google.cloud.bigquery.storage.v1.ReadStream streams = 10 [(.google.api.field_behavior) = OUTPUT_ONLY];
      {::_pbi::TcParser::FastMtR1,
       {82, 0, 5,
        PROTOBUF_FIELD_OFFSET(ReadSession, _impl_.streams_)}},
      {::_pbi::TcParser::MiniParse, {}},
      // int64 estimated_total_bytes_scanned = 12 [(.google.api.field_behavior) = OUTPUT_ONLY];
      {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(ReadSession, _impl_.estimated_total_bytes_scanned_), 7>(),
       {96, 7, 0,
        PROTOBUF_FIELD_OFFSET(ReadSession, _impl_.estimated_total_bytes_scanned_)}},
      // string trace_id = 13 [(.google.api.field_behavior) = OPTIONAL];
      {::_pbi::TcParser::FastUS1,
       {106, 3, 0,
        PROTOBUF_FIELD_OFFSET(ReadSession, _impl_.trace_id_)}},
      // int64 estimated_row_count = 14 [(.google.api.field_behavior) = OUTPUT_ONLY];
      {::_pbi::TcParser::SingularVarintNoZag1<::uint64_t, offsetof(ReadSession, _impl_.estimated_row_count_), 8>(),
       {112, 8, 0,
        PROTOBUF_FIELD_OFFSET(ReadSession, _impl_.estimated_row_count_)}},
      {::_pbi::TcParser::MiniParse, {}},
    }}, {{
      65535, 65535
    }}, {{
      // string name = 1 [(.google.api.field_behavior) = OUTPUT_ONLY];
      {PROTOBUF_FIELD_OFFSET(ReadSession, _impl_.name_), _Internal::kHasBitsOffset + 1, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // .google.protobuf.Timestamp expire_time = 2 [(.google.api.field_behavior) = OUTPUT_ONLY];
      {PROTOBUF_FIELD_OFFSET(ReadSession, _impl_.expire_time_), _Internal::kHasBitsOffset + 4, 0, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
      // .google.cloud.bigquery.storage.v1.DataFormat data_format = 3 [(.google.api.field_behavior) = IMMUTABLE];
      {PROTOBUF_FIELD_OFFSET(ReadSession, _impl_.data_format_), _Internal::kHasBitsOffset + 9, 0, (0 | ::_fl::kFcOptional | ::_fl::kOpenEnum)},
      // .google.cloud.bigquery.storage.v1.AvroSchema avro_schema = 4 [(.google.api.field_behavior) = OUTPUT_ONLY];
      {PROTOBUF_FIELD_OFFSET(ReadSession, _impl_.schema_.avro_schema_), _Internal::kOneofCaseOffset + 0, 1, (0 | ::_fl::kFcOneof | ::_fl::kMessage | ::_fl::kTvTable)},
      // .google.cloud.bigquery.storage.v1.ArrowSchema arrow_schema = 5 [(.google.api.field_behavior) = OUTPUT_ONLY];
      {PROTOBUF_FIELD_OFFSET(ReadSession, _impl_.schema_.arrow_schema_), _Internal::kOneofCaseOffset + 0, 2, (0 | ::_fl::kFcOneof | ::_fl::kMessage | ::_fl::kTvTable)},
      // string table = 6 [(.google.api.field_behavior) = IMMUTABLE, (.google.api.resource_reference) = {
      {PROTOBUF_FIELD_OFFSET(ReadSession, _impl_.table_), _Internal::kHasBitsOffset + 2, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // .google.cloud.bigquery.storage.v1.ReadSession.TableModifiers table_modifiers = 7 [(.google.api.field_behavior) = OPTIONAL];
      {PROTOBUF_FIELD_OFFSET(ReadSession, _impl_.table_modifiers_), _Internal::kHasBitsOffset + 5, 3, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
      // .google.cloud.bigquery.storage.v1.ReadSession.TableReadOptions read_options = 8 [(.google.api.field_behavior) = OPTIONAL];
      {PROTOBUF_FIELD_OFFSET(ReadSession, _impl_.read_options_), _Internal::kHasBitsOffset + 6, 4, (0 | ::_fl::kFcOptional | ::_fl::kMessage | ::_fl::kTvTable)},
      // repeated .google.cloud.bigquery.storage.v1.ReadStream streams = 10 [(.google.api.field_behavior) = OUTPUT_ONLY];
      {PROTOBUF_FIELD_OFFSET(ReadSession, _impl_.streams_), _Internal::kHasBitsOffset + 0, 5, (0 | ::_fl::kFcRepeated | ::_fl::kMessage | ::_fl::kTvTable)},
      // int64 estimated_total_bytes_scanned = 12 [(.google.api.field_behavior) = OUTPUT_ONLY];
      {PROTOBUF_FIELD_OFFSET(ReadSession, _impl_.estimated_total_bytes_scanned_), _Internal::kHasBitsOffset + 7, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt64)},
      // string trace_id = 13 [(.google.api.field_behavior) = OPTIONAL];
      {PROTOBUF_FIELD_OFFSET(ReadSession, _impl_.trace_id_), _Internal::kHasBitsOffset + 3, 0, (0 | ::_fl::kFcOptional | ::_fl::kUtf8String | ::_fl::kRepAString)},
      // int64 estimated_row_count = 14 [(.google.api.field_behavior) = OUTPUT_ONLY];
      {PROTOBUF_FIELD_OFFSET(ReadSession, _impl_.estimated_row_count_), _Internal::kHasBitsOffset + 8, 0, (0 | ::_fl::kFcOptional | ::_fl::kInt64)},
    }},
    {{
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::google::protobuf::Timestamp>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::google::protobuf::Timestamp_globals_},
        #endif
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::google::cloud::bigquery::storage::v1::AvroSchema>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::google::cloud::bigquery::storage::v1::AvroSchema_globals_},
        #endif
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::google::cloud::bigquery::storage::v1::ArrowSchema>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::google::cloud::bigquery::storage::v1::ArrowSchema_globals_},
        #endif
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::google::cloud::bigquery::storage::v1::ReadSession_TableModifiers>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::google::cloud::bigquery::storage::v1::ReadSession_TableModifiers_globals_},
        #endif
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::google::cloud::bigquery::storage::v1::ReadSession_TableReadOptions>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::google::cloud::bigquery::storage::v1::ReadSession_TableReadOptions_globals_},
        #endif
        #ifndef PROTOBUF_MESSAGE_GLOBALS
        {::_pbi::TcParser::GetTable<::google::cloud::bigquery::storage::v1::ReadStream>()},
        #else
        {::_pbi::FieldAuxMessageGlobals(), &::google::cloud::bigquery::storage::v1::ReadStream_globals_},
        #endif
    }},
    {{
      "\54\4\0\0\0\0\5\0\0\0\0\10\0\0\0\0"
      "google.cloud.bigquery.storage.v1.ReadSession"
      "name"
      "table"
      "trace_id"
    }},
  };
}


inline constexpr ReadSession::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    ::_pbi::ConstantInitialized) noexcept
      : _cached_size_{0},
        streams_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::google::cloud::bigquery::storage::v1::ReadSession,
            PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ReadSession, _impl_.streams_)>()
         }
        ,
        name_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        table_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        trace_id_(
            &::google::protobuf::internal::fixed_address_empty_string,
            ::_pbi::ConstantInitialized()),
        expire_time_{nullptr},
        table_modifiers_{nullptr},
        read_options_{nullptr},
        estimated_total_bytes_scanned_{::int64_t{0}},
        estimated_row_count_{::int64_t{0}},
        data_format_{static_cast< ::google::cloud::bigquery::storage::v1::DataFormat >(0)},
        schema_{},
        _oneof_case_{} {}

template <typename>
constexpr ReadSession::ReadSession(::_pbi::ConstantInitialized,
                       const ::_pbi::ClassData* PROTOBUF_NONNULL class_data)
    : ::google::protobuf::Message(
#if defined(PROTOBUF_CUSTOM_VTABLE)
          class_data
#endif  // PROTOBUF_CUSTOM_VTABLE
          ),
      _impl_(internal_visibility(), ::_pbi::ConstantInitialized()) {
}
inline void* PROTOBUF_NONNULL ReadSession::PlacementNew_(
    const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena) {
  return ::new (mem) ReadSession(arena);
}
constexpr auto ReadSession::InternalNewImpl_() {
  return ::google::protobuf::internal::MessageCreator::CopyInit(sizeof(ReadSession), alignof(ReadSession));
}
constexpr auto ReadSession::InternalGenerateClassData_(
    const MessageLite& prototype,
    const ::google::protobuf::internal::TcParseTableBase* tc_table) {
  return ::google::protobuf::internal::ClassDataFull{
      ::google::protobuf::internal::ClassData{
          &prototype,
#ifndef PROTOBUF_MESSAGE_GLOBALS
          &_table_.header,
#else
          tc_table,
#endif
          nullptr,  // IsInitialized
          &ReadSession::MergeImpl,
          ::google::protobuf::Message::GetNewImpl<ReadSession>(),
#if defined(PROTOBUF_CUSTOM_VTABLE)
          &ReadSession::SharedDtor,
          ::google::protobuf::Message::GetClearImpl<ReadSession>(), &ReadSession::ByteSizeLong,
              &ReadSession::_InternalSerialize,
#endif  // PROTOBUF_CUSTOM_VTABLE
          PROTOBUF_FIELD_OFFSET(ReadSession, _impl_._cached_size_),
          false,
      },
#ifdef PROTOBUF_MESSAGE_GLOBALS
      &file_reflection_data[2],
#else   // !PROTOBUF_MESSAGE_GLOBALS
      &::_pbi::kDescriptorMethods,
      &descriptor_table_google_2fcloud_2fbigquery_2fstorage_2fv1_2fstream_2eproto,
      nullptr,  // tracker
#endif  // PROTOBUF_MESSAGE_GLOBALS
  };
}
struct ReadSessionGlobalsTypeInternal : ::_pbi::MessageGlobalsBase {
  constexpr ReadSessionGlobalsTypeInternal()
      :
#ifndef PROTOBUF_MESSAGE_GLOBALS
        _default(::_pbi::ConstantInitialized{},
                 ReadSession_class_data_.base())
#else   // !PROTOBUF_MESSAGE_GLOBALS
        MessageGlobalsBase(ReadSession::InternalGenerateClassData_(
            _default, &ReadSession_globals_._table.header)),
        _default(::_pbi::ConstantInitialized{}, GetClassData()),
        _table(::_pbi::PrivateAccess::GenerateParseTable<ReadSession>(
            GetClassData()))
#endif  // PROTOBUF_MESSAGE_GLOBALS
  {
  }
  ~ReadSessionGlobalsTypeInternal() {}
  union {
    alignas(::_pbi::kMaxMessageAlignment) ReadSession _default;
  };
#ifdef PROTOBUF_MESSAGE_GLOBALS
  decltype(::_pbi::PrivateAccess::GenerateParseTable<ReadSession>(
      ::std::declval<const ::_pbi::ClassData*>())) _table;
#endif
};
#ifdef PROTOBUF_MESSAGE_GLOBALS
static_assert(PROTOBUF_FIELD_OFFSET(ReadSessionGlobalsTypeInternal, _default) ==
              ::_pbi::MessageGlobalsBase::OffsetToDefault());
#endif  // PROTOBUF_MESSAGE_GLOBALS

PROTOBUF_ATTRIBUTE_NO_DESTROY PROTOBUF_CONSTINIT
    PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 PROTOBUF_MESSAGE_GLOBALS_CONST ReadSessionGlobalsTypeInternal ReadSession_globals_
        PROTOBUF_MESSAGE_GLOBALS_SECTION(.data.rel.ro);
#if defined(PROTOBUF_CUSTOM_VTABLE)
namespace {
const ::_pbi::ClassData* ReadSession_get_class_data() {
#ifdef PROTOBUF_MESSAGE_GLOBALS
  return ReadSession_globals_.GetClassData();
#else
  return ReadSession_class_data_.base();
#endif  // PROTOBUF_MESSAGE_GLOBALS
}
}  // namespace
#endif  // PROTOBUF_CUSTOM_VTABLE
}  // namespace v1
}  // namespace storage
}  // namespace bigquery
}  // namespace cloud
}  // namespace google
static const ::_pb::EnumDescriptor* PROTOBUF_NONNULL
    file_level_enum_descriptors_google_2fcloud_2fbigquery_2fstorage_2fv1_2fstream_2eproto[4];
static constexpr const ::_pb::ServiceDescriptor* PROTOBUF_NONNULL* PROTOBUF_NULLABLE
    file_level_service_descriptors_google_2fcloud_2fbigquery_2fstorage_2fv1_2fstream_2eproto = nullptr;
const ::uint32_t
    TableStruct_google_2fcloud_2fbigquery_2fstorage_2fv1_2fstream_2eproto::offsets[] ABSL_ATTRIBUTE_SECTION_VARIABLE(
        protodesc_cold) = {
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ReadSession_TableModifiers, _impl_._has_bits_),
        4, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ReadSession_TableModifiers, _impl_.snapshot_time_),
        0,
        0x085, // bitmap
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ReadSession_TableReadOptions, _impl_._has_bits_),
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ReadSession_TableReadOptions, _impl_._oneof_case_[0]),
        10, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ReadSession_TableReadOptions, _impl_.selected_fields_),
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ReadSession_TableReadOptions, _impl_.row_restriction_),
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ReadSession_TableReadOptions, _impl_.output_format_serialization_options_),
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ReadSession_TableReadOptions, _impl_.output_format_serialization_options_),
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ReadSession_TableReadOptions, _impl_.sample_percentage_),
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ReadSession_TableReadOptions, _impl_.output_format_serialization_options_),
        0,
        1,
        ~0u,
        ~0u,
        2,
        0x085, // bitmap
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ReadSession, _impl_._has_bits_),
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ReadSession, _impl_._oneof_case_[0]),
        17, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ReadSession, _impl_.name_),
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ReadSession, _impl_.expire_time_),
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ReadSession, _impl_.data_format_),
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ReadSession, _impl_.schema_),
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ReadSession, _impl_.schema_),
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ReadSession, _impl_.table_),
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ReadSession, _impl_.table_modifiers_),
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ReadSession, _impl_.read_options_),
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ReadSession, _impl_.streams_),
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ReadSession, _impl_.estimated_total_bytes_scanned_),
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ReadSession, _impl_.estimated_row_count_),
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ReadSession, _impl_.trace_id_),
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ReadSession, _impl_.schema_),
        1,
        4,
        9,
        ~0u,
        ~0u,
        2,
        5,
        6,
        0,
        7,
        8,
        3,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ReadStream, _impl_._has_bits_),
        4, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ReadStream, _impl_.name_),
        0,
        0x081, // bitmap
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::WriteStream, _impl_._has_bits_),
        10, // hasbit index offset
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::WriteStream, _impl_.name_),
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::WriteStream, _impl_.type_),
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::WriteStream, _impl_.create_time_),
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::WriteStream, _impl_.commit_time_),
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::WriteStream, _impl_.table_schema_),
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::WriteStream, _impl_.write_mode_),
        PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::WriteStream, _impl_.location_),
        0,
        5,
        2,
        3,
        4,
        6,
        1,
};

static const ::_pbi::MigrationSchema
    schemas[] ABSL_ATTRIBUTE_SECTION_VARIABLE(protodesc_cold) = {
        {0, sizeof(::google::cloud::bigquery::storage::v1::ReadSession_TableModifiers)},
        {5, sizeof(::google::cloud::bigquery::storage::v1::ReadSession_TableReadOptions)},
        {20, sizeof(::google::cloud::bigquery::storage::v1::ReadSession)},
        {49, sizeof(::google::cloud::bigquery::storage::v1::ReadStream)},
        {54, sizeof(::google::cloud::bigquery::storage::v1::WriteStream)},
};
static const ::_pbi::MessageGlobalsBase* PROTOBUF_NONNULL const
    file_message_globals[] = {
        &::google::cloud::bigquery::storage::v1::ReadSession_TableModifiers_globals_,
        &::google::cloud::bigquery::storage::v1::ReadSession_TableReadOptions_globals_,
        &::google::cloud::bigquery::storage::v1::ReadSession_globals_,
        &::google::cloud::bigquery::storage::v1::ReadStream_globals_,
        &::google::cloud::bigquery::storage::v1::WriteStream_globals_,
};
const char descriptor_table_protodef_google_2fcloud_2fbigquery_2fstorage_2fv1_2fstream_2eproto[] ABSL_ATTRIBUTE_SECTION_VARIABLE(
    protodesc_cold) = {
    "\n-google/cloud/bigquery/storage/v1/strea"
    "m.proto\022 google.cloud.bigquery.storage.v"
    "1\032\037google/api/field_behavior.proto\032\031goog"
    "le/api/resource.proto\032,google/cloud/bigq"
    "uery/storage/v1/arrow.proto\032+google/clou"
    "d/bigquery/storage/v1/avro.proto\032,google"
    "/cloud/bigquery/storage/v1/table.proto\032\037"
    "google/protobuf/timestamp.proto\"\216\n\n\013Read"
    "Session\022\022\n\004name\030\001 \001(\tB\004\342A\001\003\0225\n\013expire_ti"
    "me\030\002 \001(\0132\032.google.protobuf.TimestampB\004\342A"
    "\001\003\022G\n\013data_format\030\003 \001(\0162,.google.cloud.b"
    "igquery.storage.v1.DataFormatB\004\342A\001\005\022I\n\013a"
    "vro_schema\030\004 \001(\0132,.google.cloud.bigquery"
    ".storage.v1.AvroSchemaB\004\342A\001\003H\000\022K\n\014arrow_"
    "schema\030\005 \001(\0132-.google.cloud.bigquery.sto"
    "rage.v1.ArrowSchemaB\004\342A\001\003H\000\0225\n\005table\030\006 \001"
    "(\tB&\342A\001\005\372A\037\n\035bigquery.googleapis.com/Tab"
    "le\022[\n\017table_modifiers\030\007 \001(\0132<.google.clo"
    "ud.bigquery.storage.v1.ReadSession.Table"
    "ModifiersB\004\342A\001\001\022Z\n\014read_options\030\010 \001(\0132>."
    "google.cloud.bigquery.storage.v1.ReadSes"
    "sion.TableReadOptionsB\004\342A\001\001\022C\n\007streams\030\n"
    " \003(\0132,.google.cloud.bigquery.storage.v1."
    "ReadStreamB\004\342A\001\003\022+\n\035estimated_total_byte"
    "s_scanned\030\014 \001(\003B\004\342A\001\003\022!\n\023estimated_row_c"
    "ount\030\016 \001(\003B\004\342A\001\003\022\026\n\010trace_id\030\r \001(\tB\004\342A\001\001"
    "\032C\n\016TableModifiers\0221\n\rsnapshot_time\030\001 \001("
    "\0132\032.google.protobuf.Timestamp\032\371\002\n\020TableR"
    "eadOptions\022\027\n\017selected_fields\030\001 \003(\t\022\027\n\017r"
    "ow_restriction\030\002 \001(\t\022h\n\033arrow_serializat"
    "ion_options\030\003 \001(\0132;.google.cloud.bigquer"
    "y.storage.v1.ArrowSerializationOptionsB\004"
    "\342A\001\001H\000\022f\n\032avro_serialization_options\030\004 \001"
    "(\0132:.google.cloud.bigquery.storage.v1.Av"
    "roSerializationOptionsB\004\342A\001\001H\000\022$\n\021sample"
    "_percentage\030\005 \001(\001B\004\342A\001\001H\001\210\001\001B%\n#output_f"
    "ormat_serialization_optionsB\024\n\022_sample_p"
    "ercentage:k\352Ah\n*bigquerystorage.googleap"
    "is.com/ReadSession\022:projects/{project}/l"
    "ocations/{location}/sessions/{session}B\010"
    "\n\006schema\"\235\001\n\nReadStream\022\022\n\004name\030\001 \001(\tB\004\342"
    "A\001\003:{\352Ax\n)bigquerystorage.googleapis.com"
    "/ReadStream\022Kprojects/{project}/location"
    "s/{location}/sessions/{session}/streams/"
    "{stream}\"\202\005\n\013WriteStream\022\022\n\004name\030\001 \001(\tB\004"
    "\342A\001\003\022F\n\004type\030\002 \001(\01622.google.cloud.bigque"
    "ry.storage.v1.WriteStream.TypeB\004\342A\001\005\0225\n\013"
    "create_time\030\003 \001(\0132\032.google.protobuf.Time"
    "stampB\004\342A\001\003\0225\n\013commit_time\030\004 \001(\0132\032.googl"
    "e.protobuf.TimestampB\004\342A\001\003\022I\n\014table_sche"
    "ma\030\005 \001(\0132-.google.cloud.bigquery.storage"
    ".v1.TableSchemaB\004\342A\001\003\022Q\n\nwrite_mode\030\007 \001("
    "\01627.google.cloud.bigquery.storage.v1.Wri"
    "teStream.WriteModeB\004\342A\001\005\022\026\n\010location\030\010 \001"
    "(\tB\004\342A\001\005\"F\n\004Type\022\024\n\020TYPE_UNSPECIFIED\020\000\022\r"
    "\n\tCOMMITTED\020\001\022\013\n\007PENDING\020\002\022\014\n\010BUFFERED\020\003"
    "\"3\n\tWriteMode\022\032\n\026WRITE_MODE_UNSPECIFIED\020"
    "\000\022\n\n\006INSERT\020\001:v\352As\n*bigquerystorage.goog"
    "leapis.com/WriteStream\022Eprojects/{projec"
    "t}/datasets/{dataset}/tables/{table}/str"
    "eams/{stream}*>\n\nDataFormat\022\033\n\027DATA_FORM"
    "AT_UNSPECIFIED\020\000\022\010\n\004AVRO\020\001\022\t\n\005ARROW\020\002*I\n"
    "\017WriteStreamView\022!\n\035WRITE_STREAM_VIEW_UN"
    "SPECIFIED\020\000\022\t\n\005BASIC\020\001\022\010\n\004FULL\020\002B\273\001\n$com"
    ".google.cloud.bigquery.storage.v1B\013Strea"
    "mProtoP\001Z>cloud.google.com/go/bigquery/s"
    "torage/apiv1/storagepb;storagepb\252\002 Googl"
    "e.Cloud.BigQuery.Storage.V1\312\002 Google\\Clo"
    "ud\\BigQuery\\Storage\\V1b\006proto3"
};
static const ::_pbi::DescriptorTable* PROTOBUF_NONNULL const
    descriptor_table_google_2fcloud_2fbigquery_2fstorage_2fv1_2fstream_2eproto_deps[6] = {
        &::descriptor_table_google_2fapi_2ffield_5fbehavior_2eproto,
        &::descriptor_table_google_2fapi_2fresource_2eproto,
        &::descriptor_table_google_2fcloud_2fbigquery_2fstorage_2fv1_2farrow_2eproto,
        &::descriptor_table_google_2fcloud_2fbigquery_2fstorage_2fv1_2favro_2eproto,
        &::descriptor_table_google_2fcloud_2fbigquery_2fstorage_2fv1_2ftable_2eproto,
        &::descriptor_table_google_2fprotobuf_2ftimestamp_2eproto,
};
static ::absl::once_flag descriptor_table_google_2fcloud_2fbigquery_2fstorage_2fv1_2fstream_2eproto_once;
PROTOBUF_CONSTINIT const ::_pbi::DescriptorTable descriptor_table_google_2fcloud_2fbigquery_2fstorage_2fv1_2fstream_2eproto = {
    false,
    false,
    2750,
    descriptor_table_protodef_google_2fcloud_2fbigquery_2fstorage_2fv1_2fstream_2eproto,
    "google/cloud/bigquery/storage/v1/stream.proto",
    &descriptor_table_google_2fcloud_2fbigquery_2fstorage_2fv1_2fstream_2eproto_once,
    descriptor_table_google_2fcloud_2fbigquery_2fstorage_2fv1_2fstream_2eproto_deps,
    6,
    5,
    schemas,
    file_message_globals,
    TableStruct_google_2fcloud_2fbigquery_2fstorage_2fv1_2fstream_2eproto::offsets,
    file_level_enum_descriptors_google_2fcloud_2fbigquery_2fstorage_2fv1_2fstream_2eproto,
    file_level_service_descriptors_google_2fcloud_2fbigquery_2fstorage_2fv1_2fstream_2eproto,
};
namespace google {
namespace cloud {
namespace bigquery {
namespace storage {
namespace v1 {
[[nodiscard]] const ::google::protobuf::EnumDescriptor* PROTOBUF_NONNULL
WriteStream_Type_descriptor() {
  ::google::protobuf::internal::AssignDescriptors(&descriptor_table_google_2fcloud_2fbigquery_2fstorage_2fv1_2fstream_2eproto);
  return file_level_enum_descriptors_google_2fcloud_2fbigquery_2fstorage_2fv1_2fstream_2eproto[0];
}
PROTOBUF_CONSTINIT const uint32_t WriteStream_Type_internal_data_[] = {
    262144u, 0u, };
[[nodiscard]] const ::google::protobuf::EnumDescriptor* PROTOBUF_NONNULL
WriteStream_WriteMode_descriptor() {
  ::google::protobuf::internal::AssignDescriptors(&descriptor_table_google_2fcloud_2fbigquery_2fstorage_2fv1_2fstream_2eproto);
  return file_level_enum_descriptors_google_2fcloud_2fbigquery_2fstorage_2fv1_2fstream_2eproto[1];
}
PROTOBUF_CONSTINIT const uint32_t WriteStream_WriteMode_internal_data_[] = {
    131072u, 0u, };
[[nodiscard]] const ::google::protobuf::EnumDescriptor* PROTOBUF_NONNULL
DataFormat_descriptor() {
  ::google::protobuf::internal::AssignDescriptors(&descriptor_table_google_2fcloud_2fbigquery_2fstorage_2fv1_2fstream_2eproto);
  return file_level_enum_descriptors_google_2fcloud_2fbigquery_2fstorage_2fv1_2fstream_2eproto[2];
}
PROTOBUF_CONSTINIT const uint32_t DataFormat_internal_data_[] = {
    196608u, 0u, };
[[nodiscard]] const ::google::protobuf::EnumDescriptor* PROTOBUF_NONNULL
WriteStreamView_descriptor() {
  ::google::protobuf::internal::AssignDescriptors(&descriptor_table_google_2fcloud_2fbigquery_2fstorage_2fv1_2fstream_2eproto);
  return file_level_enum_descriptors_google_2fcloud_2fbigquery_2fstorage_2fv1_2fstream_2eproto[3];
}
PROTOBUF_CONSTINIT const uint32_t WriteStreamView_internal_data_[] = {
    196608u, 0u, };
// ===================================================================

void ReadSession_TableModifiers::clear_snapshot_time() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.snapshot_time_ != nullptr) _impl_.snapshot_time_->Clear();
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
}
ReadSession_TableModifiers::ReadSession_TableModifiers(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, ReadSession_TableModifiers_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:google.cloud.bigquery.storage.v1.ReadSession.TableModifiers)
}
PROTOBUF_NDEBUG_INLINE ReadSession_TableModifiers::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::google::cloud::bigquery::storage::v1::ReadSession_TableModifiers& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0} {}

ReadSession_TableModifiers::ReadSession_TableModifiers(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const ReadSession_TableModifiers& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, ReadSession_TableModifiers_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  ReadSession_TableModifiers* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.snapshot_time_ = (CheckHasBit(cached_has_bits, 0x00000001U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.snapshot_time_)
                : nullptr;

  // @@protoc_insertion_point(copy_constructor:google.cloud.bigquery.storage.v1.ReadSession.TableModifiers)
}
PROTOBUF_NDEBUG_INLINE ReadSession_TableModifiers::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0} {}

inline void ReadSession_TableModifiers::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  _impl_.snapshot_time_ = {};
}
ReadSession_TableModifiers::~ReadSession_TableModifiers() {
  // @@protoc_insertion_point(destructor:google.cloud.bigquery.storage.v1.ReadSession.TableModifiers)
  SharedDtor(*this);
}
inline void ReadSession_TableModifiers::SharedDtor(MessageLite& self) {
  ReadSession_TableModifiers& this_ = static_cast<ReadSession_TableModifiers&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  delete this_._impl_.snapshot_time_;
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull ReadSession_TableModifiers_class_data_ =
        ReadSession_TableModifiers::InternalGenerateClassData_(ReadSession_TableModifiers_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
ReadSession_TableModifiers::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&ReadSession_TableModifiers_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(ReadSession_TableModifiers_class_data_.tc_table);
  return ReadSession_TableModifiers_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
ReadSession_TableModifiers::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&ReadSession_TableModifiers_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&ReadSession_TableModifiers_globals_));
  return ReadSession_TableModifiers_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const ReadSession_TableModifiers::ParseTableT_
    ReadSession_TableModifiers::_table_ =
        ReadSession_TableModifiers::InternalGenerateParseTable_(ReadSession_TableModifiers_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void ReadSession_TableModifiers::Clear() {
// @@protoc_insertion_point(message_clear_start:google.cloud.bigquery.storage.v1.ReadSession.TableModifiers)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    ABSL_DCHECK(_impl_.snapshot_time_ != nullptr);
    _impl_.snapshot_time_->Clear();
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL ReadSession_TableModifiers::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const ReadSession_TableModifiers& this_ = static_cast<const ReadSession_TableModifiers&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL ReadSession_TableModifiers::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const ReadSession_TableModifiers& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:google.cloud.bigquery.storage.v1.ReadSession.TableModifiers)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // .google.protobuf.Timestamp snapshot_time = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        1, *this_._impl_.snapshot_time_, this_._impl_.snapshot_time_->GetCachedSize(), target,
        stream);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:google.cloud.bigquery.storage.v1.ReadSession.TableModifiers)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t ReadSession_TableModifiers::ByteSizeLong(const MessageLite& base) {
  const ReadSession_TableModifiers& this_ = static_cast<const ReadSession_TableModifiers&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t ReadSession_TableModifiers::ByteSizeLong() const {
  const ReadSession_TableModifiers& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:google.cloud.bigquery.storage.v1.ReadSession.TableModifiers)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

   {
    // .google.protobuf.Timestamp snapshot_time = 1;
    cached_has_bits = this_._impl_._has_bits_[0];
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.snapshot_time_);
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void ReadSession_TableModifiers::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<ReadSession_TableModifiers*>(&to_msg);
  auto& from = static_cast<const ReadSession_TableModifiers&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:google.cloud.bigquery.storage.v1.ReadSession.TableModifiers)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    ABSL_DCHECK(from._impl_.snapshot_time_ != nullptr);
    if (_this->_impl_.snapshot_time_ == nullptr) {
      _this->_impl_.snapshot_time_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.snapshot_time_);
    } else {
      _this->_impl_.snapshot_time_->MergeFrom(*from._impl_.snapshot_time_);
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void ReadSession_TableModifiers::CopyFrom(const ReadSession_TableModifiers& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:google.cloud.bigquery.storage.v1.ReadSession.TableModifiers)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void ReadSession_TableModifiers::InternalSwap(ReadSession_TableModifiers* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  swap(_impl_.snapshot_time_, other->_impl_.snapshot_time_);
}

::google::protobuf::Metadata ReadSession_TableModifiers::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

void ReadSession_TableReadOptions::set_allocated_arrow_serialization_options(::google::cloud::bigquery::storage::v1::ArrowSerializationOptions* PROTOBUF_NULLABLE arrow_serialization_options) {
  ::google::protobuf::Arena* message_arena = GetArena();
  clear_output_format_serialization_options();
  if (arrow_serialization_options) {
    ::google::protobuf::Arena* submessage_arena = reinterpret_cast<::google::protobuf::Message*>(arrow_serialization_options)->GetArena();
    if (message_arena != submessage_arena) {
      arrow_serialization_options = ::google::protobuf::internal::GetOwnedMessage(message_arena, arrow_serialization_options, submessage_arena);
    }
    set_has_arrow_serialization_options();
    _impl_.output_format_serialization_options_.arrow_serialization_options_ = arrow_serialization_options;
  }
  // @@protoc_insertion_point(field_set_allocated:google.cloud.bigquery.storage.v1.ReadSession.TableReadOptions.arrow_serialization_options)
}
void ReadSession_TableReadOptions::clear_arrow_serialization_options() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (output_format_serialization_options_case() == kArrowSerializationOptions) {
    if (GetArena() == nullptr) {
      delete _impl_.output_format_serialization_options_.arrow_serialization_options_;
    } else if (::google::protobuf::internal::DebugHardenClearOneofMessageOnArena()) {
      ::google::protobuf::internal::MaybePoisonAfterClear(_impl_.output_format_serialization_options_.arrow_serialization_options_);
    }
    clear_has_output_format_serialization_options();
  }
}
void ReadSession_TableReadOptions::set_allocated_avro_serialization_options(::google::cloud::bigquery::storage::v1::AvroSerializationOptions* PROTOBUF_NULLABLE avro_serialization_options) {
  ::google::protobuf::Arena* message_arena = GetArena();
  clear_output_format_serialization_options();
  if (avro_serialization_options) {
    ::google::protobuf::Arena* submessage_arena = reinterpret_cast<::google::protobuf::Message*>(avro_serialization_options)->GetArena();
    if (message_arena != submessage_arena) {
      avro_serialization_options = ::google::protobuf::internal::GetOwnedMessage(message_arena, avro_serialization_options, submessage_arena);
    }
    set_has_avro_serialization_options();
    _impl_.output_format_serialization_options_.avro_serialization_options_ = avro_serialization_options;
  }
  // @@protoc_insertion_point(field_set_allocated:google.cloud.bigquery.storage.v1.ReadSession.TableReadOptions.avro_serialization_options)
}
void ReadSession_TableReadOptions::clear_avro_serialization_options() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (output_format_serialization_options_case() == kAvroSerializationOptions) {
    if (GetArena() == nullptr) {
      delete _impl_.output_format_serialization_options_.avro_serialization_options_;
    } else if (::google::protobuf::internal::DebugHardenClearOneofMessageOnArena()) {
      ::google::protobuf::internal::MaybePoisonAfterClear(_impl_.output_format_serialization_options_.avro_serialization_options_);
    }
    clear_has_output_format_serialization_options();
  }
}
ReadSession_TableReadOptions::ReadSession_TableReadOptions(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, ReadSession_TableReadOptions_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:google.cloud.bigquery.storage.v1.ReadSession.TableReadOptions)
}
PROTOBUF_NDEBUG_INLINE ReadSession_TableReadOptions::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::google::cloud::bigquery::storage::v1::ReadSession_TableReadOptions& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        selected_fields_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::google::cloud::bigquery::storage::v1::ReadSession_TableReadOptions,
              PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ReadSession_TableReadOptions, _impl_.selected_fields_)>()
          , from.selected_fields_
        }
        ,
        row_restriction_(arena, from.row_restriction_),
        output_format_serialization_options_{},
        _oneof_case_{from._oneof_case_[0]} {}

ReadSession_TableReadOptions::ReadSession_TableReadOptions(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const ReadSession_TableReadOptions& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, ReadSession_TableReadOptions_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  ReadSession_TableReadOptions* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  _impl_.sample_percentage_ = from._impl_.sample_percentage_;
  switch (output_format_serialization_options_case()) {
    case OUTPUT_FORMAT_SERIALIZATION_OPTIONS_NOT_SET:
      break;
      case kArrowSerializationOptions:
        _impl_.output_format_serialization_options_.arrow_serialization_options_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.output_format_serialization_options_.arrow_serialization_options_);
        break;
      case kAvroSerializationOptions:
        _impl_.output_format_serialization_options_.avro_serialization_options_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.output_format_serialization_options_.avro_serialization_options_);
        break;
  }

  // @@protoc_insertion_point(copy_constructor:google.cloud.bigquery.storage.v1.ReadSession.TableReadOptions)
}
PROTOBUF_NDEBUG_INLINE ReadSession_TableReadOptions::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        selected_fields_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::google::cloud::bigquery::storage::v1::ReadSession_TableReadOptions,
            PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ReadSession_TableReadOptions, _impl_.selected_fields_)>()
         }
        ,
        row_restriction_(arena),
        output_format_serialization_options_{},
        _oneof_case_{} {}

inline void ReadSession_TableReadOptions::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  _impl_.sample_percentage_ = {};
}
ReadSession_TableReadOptions::~ReadSession_TableReadOptions() {
  // @@protoc_insertion_point(destructor:google.cloud.bigquery.storage.v1.ReadSession.TableReadOptions)
  SharedDtor(*this);
}
inline void ReadSession_TableReadOptions::SharedDtor(MessageLite& self) {
  ReadSession_TableReadOptions& this_ = static_cast<ReadSession_TableReadOptions&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.row_restriction_.Destroy();
  if (this_.has_output_format_serialization_options()) {
    this_.clear_output_format_serialization_options();
  }
  this_._impl_.~Impl_();
}

void ReadSession_TableReadOptions::clear_output_format_serialization_options() {
// @@protoc_insertion_point(one_of_clear_start:google.cloud.bigquery.storage.v1.ReadSession.TableReadOptions)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  switch (output_format_serialization_options_case()) {
    case kArrowSerializationOptions: {
      if (GetArena() == nullptr) {
        delete _impl_.output_format_serialization_options_.arrow_serialization_options_;
      } else if (::google::protobuf::internal::DebugHardenClearOneofMessageOnArena()) {
        ::google::protobuf::internal::MaybePoisonAfterClear(_impl_.output_format_serialization_options_.arrow_serialization_options_);
      }
      break;
    }
    case kAvroSerializationOptions: {
      if (GetArena() == nullptr) {
        delete _impl_.output_format_serialization_options_.avro_serialization_options_;
      } else if (::google::protobuf::internal::DebugHardenClearOneofMessageOnArena()) {
        ::google::protobuf::internal::MaybePoisonAfterClear(_impl_.output_format_serialization_options_.avro_serialization_options_);
      }
      break;
    }
    case OUTPUT_FORMAT_SERIALIZATION_OPTIONS_NOT_SET: {
      break;
    }
  }
  _impl_._oneof_case_[0] = OUTPUT_FORMAT_SERIALIZATION_OPTIONS_NOT_SET;
}


#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull ReadSession_TableReadOptions_class_data_ =
        ReadSession_TableReadOptions::InternalGenerateClassData_(ReadSession_TableReadOptions_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
ReadSession_TableReadOptions::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&ReadSession_TableReadOptions_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(ReadSession_TableReadOptions_class_data_.tc_table);
  return ReadSession_TableReadOptions_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
ReadSession_TableReadOptions::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&ReadSession_TableReadOptions_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&ReadSession_TableReadOptions_globals_));
  return ReadSession_TableReadOptions_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const ReadSession_TableReadOptions::ParseTableT_
    ReadSession_TableReadOptions::_table_ =
        ReadSession_TableReadOptions::InternalGenerateParseTable_(ReadSession_TableReadOptions_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void ReadSession_TableReadOptions::Clear() {
// @@protoc_insertion_point(message_clear_start:google.cloud.bigquery.storage.v1.ReadSession.TableReadOptions)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.selected_fields_.Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.row_restriction_.ClearNonDefaultToEmpty();
    }
  }
  _impl_.sample_percentage_ = 0;
  clear_output_format_serialization_options();
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL ReadSession_TableReadOptions::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const ReadSession_TableReadOptions& this_ = static_cast<const ReadSession_TableReadOptions&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL ReadSession_TableReadOptions::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const ReadSession_TableReadOptions& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:google.cloud.bigquery.storage.v1.ReadSession.TableReadOptions)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // repeated string selected_fields = 1;
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    for (int i = 0, n = this_._internal_selected_fields_size(); i < n; ++i) {
      const auto& s = this_._internal_selected_fields().Get(i);
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          s.data(), static_cast<int>(s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "google.cloud.bigquery.storage.v1.ReadSession.TableReadOptions.selected_fields");
      target = stream->WriteString(1, s, target);
    }
  }

  // string row_restriction = 2;
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (!this_._internal_row_restriction().empty()) {
      const ::std::string& _s = this_._internal_row_restriction();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "google.cloud.bigquery.storage.v1.ReadSession.TableReadOptions.row_restriction");
      target = stream->WriteStringMaybeAliased(2, _s, target);
    }
  }

  switch (this_.output_format_serialization_options_case()) {
    case kArrowSerializationOptions: {
      target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
          3, *this_._impl_.output_format_serialization_options_.arrow_serialization_options_, this_._impl_.output_format_serialization_options_.arrow_serialization_options_->GetCachedSize(), target,
          stream);
      break;
    }
    case kAvroSerializationOptions: {
      target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
          4, *this_._impl_.output_format_serialization_options_.avro_serialization_options_, this_._impl_.output_format_serialization_options_.avro_serialization_options_->GetCachedSize(), target,
          stream);
      break;
    }
    default:
      break;
  }
  // optional double sample_percentage = 5 [(.google.api.field_behavior) = OPTIONAL];
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    target = stream->EnsureSpace(target);
    target = ::_pbi::WireFormatLite::WriteDoubleToArray(
        5, this_._internal_sample_percentage(), target);
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:google.cloud.bigquery.storage.v1.ReadSession.TableReadOptions)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t ReadSession_TableReadOptions::ByteSizeLong(const MessageLite& base) {
  const ReadSession_TableReadOptions& this_ = static_cast<const ReadSession_TableReadOptions&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t ReadSession_TableReadOptions::ByteSizeLong() const {
  const ReadSession_TableReadOptions& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:google.cloud.bigquery.storage.v1.ReadSession.TableReadOptions)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  total_size += static_cast<bool>(0x00000004U & cached_has_bits) * 9;
  if (BatchCheckHasBit(cached_has_bits, 0x00000003U)) {
    // repeated string selected_fields = 1;
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size +=
          1 * ::google::protobuf::internal::FromIntSize(this_._internal_selected_fields().size());
      for (int i = 0, n = this_._internal_selected_fields().size(); i < n; ++i) {
        total_size += ::google::protobuf::internal::WireFormatLite::StringSize(
            this_._internal_selected_fields().Get(i));
      }
    }
    // string row_restriction = 2;
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!this_._internal_row_restriction().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_row_restriction());
      }
    }
  }
  switch (this_.output_format_serialization_options_case()) {
    // .google.cloud.bigquery.storage.v1.ArrowSerializationOptions arrow_serialization_options = 3 [(.google.api.field_behavior) = OPTIONAL];
    case kArrowSerializationOptions: {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.output_format_serialization_options_.arrow_serialization_options_);
      break;
    }
    // .google.cloud.bigquery.storage.v1.AvroSerializationOptions avro_serialization_options = 4 [(.google.api.field_behavior) = OPTIONAL];
    case kAvroSerializationOptions: {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.output_format_serialization_options_.avro_serialization_options_);
      break;
    }
    case OUTPUT_FORMAT_SERIALIZATION_OPTIONS_NOT_SET: {
      break;
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void ReadSession_TableReadOptions::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<ReadSession_TableReadOptions*>(&to_msg);
  auto& from = static_cast<const ReadSession_TableReadOptions&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:google.cloud.bigquery.storage.v1.ReadSession.TableReadOptions)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x00000007U)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _this->_internal_mutable_selected_fields()->InternalMergeFromWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), arena,
          from._internal_selected_fields());
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!from._internal_row_restriction().empty()) {
        _this->_internal_set_row_restriction(from._internal_row_restriction());
      } else {
        if (_this->_impl_.row_restriction_.IsDefault()) {
          _this->_internal_set_row_restriction("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _this->_impl_.sample_percentage_ = from._impl_.sample_percentage_;
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  if (const uint32_t oneof_from_case =
          from._impl_._oneof_case_[0]) {
    const uint32_t oneof_to_case = _this->_impl_._oneof_case_[0];
    const bool oneof_needs_init = oneof_to_case != oneof_from_case;
    if (oneof_needs_init) {
      if (oneof_to_case != 0) {
        _this->clear_output_format_serialization_options();
      }
      _this->_impl_._oneof_case_[0] = oneof_from_case;
    }

    switch (oneof_from_case) {
      case kArrowSerializationOptions: {
        if (oneof_needs_init) {
          _this->_impl_.output_format_serialization_options_.arrow_serialization_options_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.output_format_serialization_options_.arrow_serialization_options_);
        } else {
          _this->_impl_.output_format_serialization_options_.arrow_serialization_options_->MergeFrom(*from._impl_.output_format_serialization_options_.arrow_serialization_options_);
        }
        break;
      }
      case kAvroSerializationOptions: {
        if (oneof_needs_init) {
          _this->_impl_.output_format_serialization_options_.avro_serialization_options_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.output_format_serialization_options_.avro_serialization_options_);
        } else {
          _this->_impl_.output_format_serialization_options_.avro_serialization_options_->MergeFrom(*from._impl_.output_format_serialization_options_.avro_serialization_options_);
        }
        break;
      }
      case OUTPUT_FORMAT_SERIALIZATION_OPTIONS_NOT_SET:
        break;
    }
  }
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void ReadSession_TableReadOptions::CopyFrom(const ReadSession_TableReadOptions& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:google.cloud.bigquery.storage.v1.ReadSession.TableReadOptions)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void ReadSession_TableReadOptions::InternalSwap(ReadSession_TableReadOptions* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  _impl_.selected_fields_.InternalSwap(&other->_impl_.selected_fields_);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.row_restriction_, &other->_impl_.row_restriction_, arena);
  swap(_impl_.sample_percentage_, other->_impl_.sample_percentage_);
  swap(_impl_.output_format_serialization_options_, other->_impl_.output_format_serialization_options_);
  swap(_impl_._oneof_case_[0], other->_impl_._oneof_case_[0]);
}

::google::protobuf::Metadata ReadSession_TableReadOptions::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

void ReadSession::clear_expire_time() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.expire_time_ != nullptr) _impl_.expire_time_->Clear();
  ClearHasBit(_impl_._has_bits_[0], 0x00000010U);
}
void ReadSession::set_allocated_avro_schema(::google::cloud::bigquery::storage::v1::AvroSchema* PROTOBUF_NULLABLE avro_schema) {
  ::google::protobuf::Arena* message_arena = GetArena();
  clear_schema();
  if (avro_schema) {
    ::google::protobuf::Arena* submessage_arena = reinterpret_cast<::google::protobuf::Message*>(avro_schema)->GetArena();
    if (message_arena != submessage_arena) {
      avro_schema = ::google::protobuf::internal::GetOwnedMessage(message_arena, avro_schema, submessage_arena);
    }
    set_has_avro_schema();
    _impl_.schema_.avro_schema_ = avro_schema;
  }
  // @@protoc_insertion_point(field_set_allocated:google.cloud.bigquery.storage.v1.ReadSession.avro_schema)
}
void ReadSession::clear_avro_schema() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (schema_case() == kAvroSchema) {
    if (GetArena() == nullptr) {
      delete _impl_.schema_.avro_schema_;
    } else if (::google::protobuf::internal::DebugHardenClearOneofMessageOnArena()) {
      ::google::protobuf::internal::MaybePoisonAfterClear(_impl_.schema_.avro_schema_);
    }
    clear_has_schema();
  }
}
void ReadSession::set_allocated_arrow_schema(::google::cloud::bigquery::storage::v1::ArrowSchema* PROTOBUF_NULLABLE arrow_schema) {
  ::google::protobuf::Arena* message_arena = GetArena();
  clear_schema();
  if (arrow_schema) {
    ::google::protobuf::Arena* submessage_arena = reinterpret_cast<::google::protobuf::Message*>(arrow_schema)->GetArena();
    if (message_arena != submessage_arena) {
      arrow_schema = ::google::protobuf::internal::GetOwnedMessage(message_arena, arrow_schema, submessage_arena);
    }
    set_has_arrow_schema();
    _impl_.schema_.arrow_schema_ = arrow_schema;
  }
  // @@protoc_insertion_point(field_set_allocated:google.cloud.bigquery.storage.v1.ReadSession.arrow_schema)
}
void ReadSession::clear_arrow_schema() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (schema_case() == kArrowSchema) {
    if (GetArena() == nullptr) {
      delete _impl_.schema_.arrow_schema_;
    } else if (::google::protobuf::internal::DebugHardenClearOneofMessageOnArena()) {
      ::google::protobuf::internal::MaybePoisonAfterClear(_impl_.schema_.arrow_schema_);
    }
    clear_has_schema();
  }
}
ReadSession::ReadSession(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, ReadSession_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:google.cloud.bigquery.storage.v1.ReadSession)
}
PROTOBUF_NDEBUG_INLINE ReadSession::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::google::cloud::bigquery::storage::v1::ReadSession& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        streams_ {
          visibility, ::_pbi::InternalMetadataOffset::Build<
              ::google::cloud::bigquery::storage::v1::ReadSession,
              PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ReadSession, _impl_.streams_)>()
          , from.streams_
        }
        ,
        name_(arena, from.name_),
        table_(arena, from.table_),
        trace_id_(arena, from.trace_id_),
        schema_{},
        _oneof_case_{from._oneof_case_[0]} {}

ReadSession::ReadSession(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const ReadSession& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, ReadSession_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  ReadSession* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.expire_time_ = (CheckHasBit(cached_has_bits, 0x00000010U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.expire_time_)
                : nullptr;
  _impl_.table_modifiers_ = (CheckHasBit(cached_has_bits, 0x00000020U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.table_modifiers_)
                : nullptr;
  _impl_.read_options_ = (CheckHasBit(cached_has_bits, 0x00000040U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.read_options_)
                : nullptr;
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, estimated_total_bytes_scanned_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, estimated_total_bytes_scanned_),
           offsetof(Impl_, data_format_) -
               offsetof(Impl_, estimated_total_bytes_scanned_) +
               sizeof(Impl_::data_format_));
  switch (schema_case()) {
    case SCHEMA_NOT_SET:
      break;
      case kAvroSchema:
        _impl_.schema_.avro_schema_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.schema_.avro_schema_);
        break;
      case kArrowSchema:
        _impl_.schema_.arrow_schema_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.schema_.arrow_schema_);
        break;
  }

  // @@protoc_insertion_point(copy_constructor:google.cloud.bigquery.storage.v1.ReadSession)
}
PROTOBUF_NDEBUG_INLINE ReadSession::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        streams_ { visibility, ::_pbi::InternalMetadataOffset::Build<
            ::google::cloud::bigquery::storage::v1::ReadSession,
            PROTOBUF_FIELD_OFFSET(::google::cloud::bigquery::storage::v1::ReadSession, _impl_.streams_)>()
         }
        ,
        name_(arena),
        table_(arena),
        trace_id_(arena),
        schema_{},
        _oneof_case_{} {}

inline void ReadSession::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, expire_time_),
           0,
           offsetof(Impl_, data_format_) -
               offsetof(Impl_, expire_time_) +
               sizeof(Impl_::data_format_));
}
ReadSession::~ReadSession() {
  // @@protoc_insertion_point(destructor:google.cloud.bigquery.storage.v1.ReadSession)
  SharedDtor(*this);
}
inline void ReadSession::SharedDtor(MessageLite& self) {
  ReadSession& this_ = static_cast<ReadSession&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.name_.Destroy();
  this_._impl_.table_.Destroy();
  this_._impl_.trace_id_.Destroy();
  delete this_._impl_.expire_time_;
  delete this_._impl_.table_modifiers_;
  delete this_._impl_.read_options_;
  if (this_.has_schema()) {
    this_.clear_schema();
  }
  this_._impl_.~Impl_();
}

void ReadSession::clear_schema() {
// @@protoc_insertion_point(one_of_clear_start:google.cloud.bigquery.storage.v1.ReadSession)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  switch (schema_case()) {
    case kAvroSchema: {
      if (GetArena() == nullptr) {
        delete _impl_.schema_.avro_schema_;
      } else if (::google::protobuf::internal::DebugHardenClearOneofMessageOnArena()) {
        ::google::protobuf::internal::MaybePoisonAfterClear(_impl_.schema_.avro_schema_);
      }
      break;
    }
    case kArrowSchema: {
      if (GetArena() == nullptr) {
        delete _impl_.schema_.arrow_schema_;
      } else if (::google::protobuf::internal::DebugHardenClearOneofMessageOnArena()) {
        ::google::protobuf::internal::MaybePoisonAfterClear(_impl_.schema_.arrow_schema_);
      }
      break;
    }
    case SCHEMA_NOT_SET: {
      break;
    }
  }
  _impl_._oneof_case_[0] = SCHEMA_NOT_SET;
}


#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull ReadSession_class_data_ =
        ReadSession::InternalGenerateClassData_(ReadSession_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
ReadSession::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&ReadSession_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(ReadSession_class_data_.tc_table);
  return ReadSession_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
ReadSession::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&ReadSession_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&ReadSession_globals_));
  return ReadSession_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const ReadSession::ParseTableT_
    ReadSession::_table_ =
        ReadSession::InternalGenerateParseTable_(ReadSession_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void ReadSession::Clear() {
// @@protoc_insertion_point(message_clear_start:google.cloud.bigquery.storage.v1.ReadSession)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000007fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.streams_.Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.name_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      _impl_.table_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      _impl_.trace_id_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      ABSL_DCHECK(_impl_.expire_time_ != nullptr);
      _impl_.expire_time_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      ABSL_DCHECK(_impl_.table_modifiers_ != nullptr);
      _impl_.table_modifiers_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      ABSL_DCHECK(_impl_.read_options_ != nullptr);
      _impl_.read_options_->Clear();
    }
  }
  _impl_.estimated_total_bytes_scanned_ = ::int64_t{0};
  if (BatchCheckHasBit(cached_has_bits, 0x00000300U)) {
    ::memset(&_impl_.estimated_row_count_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.data_format_) -
        reinterpret_cast<char*>(&_impl_.estimated_row_count_)) + sizeof(_impl_.data_format_));
  }
  clear_schema();
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL ReadSession::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const ReadSession& this_ = static_cast<const ReadSession&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL ReadSession::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const ReadSession& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:google.cloud.bigquery.storage.v1.ReadSession)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // string name = 1 [(.google.api.field_behavior) = OUTPUT_ONLY];
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (!this_._internal_name().empty()) {
      const ::std::string& _s = this_._internal_name();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "google.cloud.bigquery.storage.v1.ReadSession.name");
      target = stream->WriteStringMaybeAliased(1, _s, target);
    }
  }

  // .google.protobuf.Timestamp expire_time = 2 [(.google.api.field_behavior) = OUTPUT_ONLY];
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        2, *this_._impl_.expire_time_, this_._impl_.expire_time_->GetCachedSize(), target,
        stream);
  }

  // .google.cloud.bigquery.storage.v1.DataFormat data_format = 3 [(.google.api.field_behavior) = IMMUTABLE];
  if (CheckHasBit(cached_has_bits, 0x00000200U)) {
    if (this_._internal_data_format() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteEnumToArray(
          3, this_._internal_data_format(), target);
    }
  }

  switch (this_.schema_case()) {
    case kAvroSchema: {
      target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
          4, *this_._impl_.schema_.avro_schema_, this_._impl_.schema_.avro_schema_->GetCachedSize(), target,
          stream);
      break;
    }
    case kArrowSchema: {
      target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
          5, *this_._impl_.schema_.arrow_schema_, this_._impl_.schema_.arrow_schema_->GetCachedSize(), target,
          stream);
      break;
    }
    default:
      break;
  }
  // string table = 6 [(.google.api.field_behavior) = IMMUTABLE, (.google.api.resource_reference) = {
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    if (!this_._internal_table().empty()) {
      const ::std::string& _s = this_._internal_table();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "google.cloud.bigquery.storage.v1.ReadSession.table");
      target = stream->WriteStringMaybeAliased(6, _s, target);
    }
  }

  // .google.cloud.bigquery.storage.v1.ReadSession.TableModifiers table_modifiers = 7 [(.google.api.field_behavior) = OPTIONAL];
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        7, *this_._impl_.table_modifiers_, this_._impl_.table_modifiers_->GetCachedSize(), target,
        stream);
  }

  // .google.cloud.bigquery.storage.v1.ReadSession.TableReadOptions read_options = 8 [(.google.api.field_behavior) = OPTIONAL];
  if (CheckHasBit(cached_has_bits, 0x00000040U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        8, *this_._impl_.read_options_, this_._impl_.read_options_->GetCachedSize(), target,
        stream);
  }

  // repeated .google.cloud.bigquery.storage.v1.ReadStream streams = 10 [(.google.api.field_behavior) = OUTPUT_ONLY];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    for (unsigned i = 0, n = static_cast<unsigned>(
                             this_._internal_streams_size());
         i < n; i++) {
      const auto& repfield = this_._internal_streams().Get(i);
      target =
          ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
              10, repfield, repfield.GetCachedSize(),
              target, stream);
    }
  }

  // int64 estimated_total_bytes_scanned = 12 [(.google.api.field_behavior) = OUTPUT_ONLY];
  if (CheckHasBit(cached_has_bits, 0x00000080U)) {
    if (this_._internal_estimated_total_bytes_scanned() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt64ToArrayWithField<12>(
              stream, this_._internal_estimated_total_bytes_scanned(), target);
    }
  }

  // string trace_id = 13 [(.google.api.field_behavior) = OPTIONAL];
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    if (!this_._internal_trace_id().empty()) {
      const ::std::string& _s = this_._internal_trace_id();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "google.cloud.bigquery.storage.v1.ReadSession.trace_id");
      target = stream->WriteStringMaybeAliased(13, _s, target);
    }
  }

  // int64 estimated_row_count = 14 [(.google.api.field_behavior) = OUTPUT_ONLY];
  if (CheckHasBit(cached_has_bits, 0x00000100U)) {
    if (this_._internal_estimated_row_count() != 0) {
      target =
          ::google::protobuf::internal::WireFormatLite::WriteInt64ToArrayWithField<14>(
              stream, this_._internal_estimated_row_count(), target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:google.cloud.bigquery.storage.v1.ReadSession)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t ReadSession::ByteSizeLong(const MessageLite& base) {
  const ReadSession& this_ = static_cast<const ReadSession&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t ReadSession::ByteSizeLong() const {
  const ReadSession& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:google.cloud.bigquery.storage.v1.ReadSession)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    // repeated .google.cloud.bigquery.storage.v1.ReadStream streams = 10 [(.google.api.field_behavior) = OUTPUT_ONLY];
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      total_size += 1UL * this_._internal_streams_size();
      for (const auto& msg : this_._internal_streams()) {
        total_size += ::google::protobuf::internal::WireFormatLite::MessageSize(msg);
      }
    }
    // string name = 1 [(.google.api.field_behavior) = OUTPUT_ONLY];
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!this_._internal_name().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_name());
      }
    }
    // string table = 6 [(.google.api.field_behavior) = IMMUTABLE, (.google.api.resource_reference) = {
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (!this_._internal_table().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_table());
      }
    }
    // string trace_id = 13 [(.google.api.field_behavior) = OPTIONAL];
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (!this_._internal_trace_id().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_trace_id());
      }
    }
    // .google.protobuf.Timestamp expire_time = 2 [(.google.api.field_behavior) = OUTPUT_ONLY];
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.expire_time_);
    }
    // .google.cloud.bigquery.storage.v1.ReadSession.TableModifiers table_modifiers = 7 [(.google.api.field_behavior) = OPTIONAL];
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.table_modifiers_);
    }
    // .google.cloud.bigquery.storage.v1.ReadSession.TableReadOptions read_options = 8 [(.google.api.field_behavior) = OPTIONAL];
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.read_options_);
    }
    // int64 estimated_total_bytes_scanned = 12 [(.google.api.field_behavior) = OUTPUT_ONLY];
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      if (this_._internal_estimated_total_bytes_scanned() != 0) {
        total_size += ::_pbi::WireFormatLite::Int64SizePlusOne(
            this_._internal_estimated_total_bytes_scanned());
      }
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000300U)) {
    // int64 estimated_row_count = 14 [(.google.api.field_behavior) = OUTPUT_ONLY];
    if (CheckHasBit(cached_has_bits, 0x00000100U)) {
      if (this_._internal_estimated_row_count() != 0) {
        total_size += ::_pbi::WireFormatLite::Int64SizePlusOne(
            this_._internal_estimated_row_count());
      }
    }
    // .google.cloud.bigquery.storage.v1.DataFormat data_format = 3 [(.google.api.field_behavior) = IMMUTABLE];
    if (CheckHasBit(cached_has_bits, 0x00000200U)) {
      if (this_._internal_data_format() != 0) {
        total_size += 1 +
                      ::_pbi::WireFormatLite::EnumSize(this_._internal_data_format());
      }
    }
  }
  switch (this_.schema_case()) {
    // .google.cloud.bigquery.storage.v1.AvroSchema avro_schema = 4 [(.google.api.field_behavior) = OUTPUT_ONLY];
    case kAvroSchema: {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.schema_.avro_schema_);
      break;
    }
    // .google.cloud.bigquery.storage.v1.ArrowSchema arrow_schema = 5 [(.google.api.field_behavior) = OUTPUT_ONLY];
    case kArrowSchema: {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.schema_.arrow_schema_);
      break;
    }
    case SCHEMA_NOT_SET: {
      break;
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void ReadSession::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<ReadSession*>(&to_msg);
  auto& from = static_cast<const ReadSession&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:google.cloud.bigquery.storage.v1.ReadSession)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x000000ffU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _this->_internal_mutable_streams()->InternalMergeFromWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), arena,
          from._internal_streams());
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!from._internal_name().empty()) {
        _this->_internal_set_name(from._internal_name());
      } else {
        if (_this->_impl_.name_.IsDefault()) {
          _this->_internal_set_name("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      if (!from._internal_table().empty()) {
        _this->_internal_set_table(from._internal_table());
      } else {
        if (_this->_impl_.table_.IsDefault()) {
          _this->_internal_set_table("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      if (!from._internal_trace_id().empty()) {
        _this->_internal_set_trace_id(from._internal_trace_id());
      } else {
        if (_this->_impl_.trace_id_.IsDefault()) {
          _this->_internal_set_trace_id("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      ABSL_DCHECK(from._impl_.expire_time_ != nullptr);
      if (_this->_impl_.expire_time_ == nullptr) {
        _this->_impl_.expire_time_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.expire_time_);
      } else {
        _this->_impl_.expire_time_->MergeFrom(*from._impl_.expire_time_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      ABSL_DCHECK(from._impl_.table_modifiers_ != nullptr);
      if (_this->_impl_.table_modifiers_ == nullptr) {
        _this->_impl_.table_modifiers_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.table_modifiers_);
      } else {
        _this->_impl_.table_modifiers_->MergeFrom(*from._impl_.table_modifiers_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      ABSL_DCHECK(from._impl_.read_options_ != nullptr);
      if (_this->_impl_.read_options_ == nullptr) {
        _this->_impl_.read_options_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.read_options_);
      } else {
        _this->_impl_.read_options_->MergeFrom(*from._impl_.read_options_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000080U)) {
      if (from._internal_estimated_total_bytes_scanned() != 0) {
        _this->_impl_.estimated_total_bytes_scanned_ = from._impl_.estimated_total_bytes_scanned_;
      }
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000300U)) {
    if (CheckHasBit(cached_has_bits, 0x00000100U)) {
      if (from._internal_estimated_row_count() != 0) {
        _this->_impl_.estimated_row_count_ = from._impl_.estimated_row_count_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000200U)) {
      if (from._internal_data_format() != 0) {
        _this->_impl_.data_format_ = from._impl_.data_format_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  if (const uint32_t oneof_from_case =
          from._impl_._oneof_case_[0]) {
    const uint32_t oneof_to_case = _this->_impl_._oneof_case_[0];
    const bool oneof_needs_init = oneof_to_case != oneof_from_case;
    if (oneof_needs_init) {
      if (oneof_to_case != 0) {
        _this->clear_schema();
      }
      _this->_impl_._oneof_case_[0] = oneof_from_case;
    }

    switch (oneof_from_case) {
      case kAvroSchema: {
        if (oneof_needs_init) {
          _this->_impl_.schema_.avro_schema_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.schema_.avro_schema_);
        } else {
          _this->_impl_.schema_.avro_schema_->MergeFrom(*from._impl_.schema_.avro_schema_);
        }
        break;
      }
      case kArrowSchema: {
        if (oneof_needs_init) {
          _this->_impl_.schema_.arrow_schema_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.schema_.arrow_schema_);
        } else {
          _this->_impl_.schema_.arrow_schema_->MergeFrom(*from._impl_.schema_.arrow_schema_);
        }
        break;
      }
      case SCHEMA_NOT_SET:
        break;
    }
  }
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void ReadSession::CopyFrom(const ReadSession& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:google.cloud.bigquery.storage.v1.ReadSession)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void ReadSession::InternalSwap(ReadSession* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  _impl_.streams_.InternalSwap(&other->_impl_.streams_);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.name_, &other->_impl_.name_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.table_, &other->_impl_.table_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.trace_id_, &other->_impl_.trace_id_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(ReadSession, _impl_.data_format_)
      + sizeof(ReadSession::_impl_.data_format_)
      - PROTOBUF_FIELD_OFFSET(ReadSession, _impl_.expire_time_)>(
          reinterpret_cast<char*>(&_impl_.expire_time_),
          reinterpret_cast<char*>(&other->_impl_.expire_time_));
  swap(_impl_.schema_, other->_impl_.schema_);
  swap(_impl_._oneof_case_[0], other->_impl_._oneof_case_[0]);
}

::google::protobuf::Metadata ReadSession::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

ReadStream::ReadStream(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, ReadStream_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:google.cloud.bigquery.storage.v1.ReadStream)
}
PROTOBUF_NDEBUG_INLINE ReadStream::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::google::cloud::bigquery::storage::v1::ReadStream& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        name_(arena, from.name_) {}

ReadStream::ReadStream(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const ReadStream& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, ReadStream_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  ReadStream* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);

  // @@protoc_insertion_point(copy_constructor:google.cloud.bigquery.storage.v1.ReadStream)
}
PROTOBUF_NDEBUG_INLINE ReadStream::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        name_(arena) {}

inline void ReadStream::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
}
ReadStream::~ReadStream() {
  // @@protoc_insertion_point(destructor:google.cloud.bigquery.storage.v1.ReadStream)
  SharedDtor(*this);
}
inline void ReadStream::SharedDtor(MessageLite& self) {
  ReadStream& this_ = static_cast<ReadStream&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.name_.Destroy();
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull ReadStream_class_data_ =
        ReadStream::InternalGenerateClassData_(ReadStream_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
ReadStream::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&ReadStream_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(ReadStream_class_data_.tc_table);
  return ReadStream_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
ReadStream::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&ReadStream_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&ReadStream_globals_));
  return ReadStream_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const ReadStream::ParseTableT_
    ReadStream::_table_ =
        ReadStream::InternalGenerateParseTable_(ReadStream_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void ReadStream::Clear() {
// @@protoc_insertion_point(message_clear_start:google.cloud.bigquery.storage.v1.ReadStream)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    _impl_.name_.ClearNonDefaultToEmpty();
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL ReadStream::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const ReadStream& this_ = static_cast<const ReadStream&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL ReadStream::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const ReadStream& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:google.cloud.bigquery.storage.v1.ReadStream)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // string name = 1 [(.google.api.field_behavior) = OUTPUT_ONLY];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_name().empty()) {
      const ::std::string& _s = this_._internal_name();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "google.cloud.bigquery.storage.v1.ReadStream.name");
      target = stream->WriteStringMaybeAliased(1, _s, target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:google.cloud.bigquery.storage.v1.ReadStream)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t ReadStream::ByteSizeLong(const MessageLite& base) {
  const ReadStream& this_ = static_cast<const ReadStream&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t ReadStream::ByteSizeLong() const {
  const ReadStream& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:google.cloud.bigquery.storage.v1.ReadStream)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

   {
    // string name = 1 [(.google.api.field_behavior) = OUTPUT_ONLY];
    cached_has_bits = this_._impl_._has_bits_[0];
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_name().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_name());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void ReadStream::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<ReadStream*>(&to_msg);
  auto& from = static_cast<const ReadStream&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(class_specific_merge_from_start:google.cloud.bigquery.storage.v1.ReadStream)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!from._internal_name().empty()) {
      _this->_internal_set_name(from._internal_name());
    } else {
      if (_this->_impl_.name_.IsDefault()) {
        _this->_internal_set_name("");
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void ReadStream::CopyFrom(const ReadStream& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:google.cloud.bigquery.storage.v1.ReadStream)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void ReadStream::InternalSwap(ReadStream* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.name_, &other->_impl_.name_, arena);
}

::google::protobuf::Metadata ReadStream::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// ===================================================================

void WriteStream::clear_create_time() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.create_time_ != nullptr) _impl_.create_time_->Clear();
  ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
}
void WriteStream::clear_commit_time() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.commit_time_ != nullptr) _impl_.commit_time_->Clear();
  ClearHasBit(_impl_._has_bits_[0], 0x00000008U);
}
void WriteStream::clear_table_schema() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.table_schema_ != nullptr) _impl_.table_schema_->Clear();
  ClearHasBit(_impl_._has_bits_[0], 0x00000010U);
}
WriteStream::WriteStream(::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, WriteStream_get_class_data()) {
#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  SharedCtor(arena);
  // @@protoc_insertion_point(arena_constructor:google.cloud.bigquery.storage.v1.WriteStream)
}
PROTOBUF_NDEBUG_INLINE WriteStream::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
    [[maybe_unused]] const ::google::cloud::bigquery::storage::v1::WriteStream& from_msg)
      : _has_bits_{from._has_bits_},
        _cached_size_{0},
        name_(arena, from.name_),
        location_(arena, from.location_) {}

WriteStream::WriteStream(
    ::google::protobuf::Arena* PROTOBUF_NULLABLE arena,
    const WriteStream& from)
#if defined(PROTOBUF_CUSTOM_VTABLE)
    : ::google::protobuf::Message(arena, WriteStream_get_class_data()) {

#else   // PROTOBUF_CUSTOM_VTABLE
    : ::google::protobuf::Message(arena) {
#endif  // PROTOBUF_CUSTOM_VTABLE
  WriteStream* const _this = this;
  (void)_this;
  _internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
  new (&_impl_) Impl_(internal_visibility(), arena, from._impl_, from);
  ::uint32_t cached_has_bits = _impl_._has_bits_[0];
  _impl_.create_time_ = (CheckHasBit(cached_has_bits, 0x00000004U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.create_time_)
                : nullptr;
  _impl_.commit_time_ = (CheckHasBit(cached_has_bits, 0x00000008U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.commit_time_)
                : nullptr;
  _impl_.table_schema_ = (CheckHasBit(cached_has_bits, 0x00000010U))
                ? ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.table_schema_)
                : nullptr;
  ::memcpy(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, type_),
           reinterpret_cast<const char*>(&from._impl_) +
               offsetof(Impl_, type_),
           offsetof(Impl_, write_mode_) -
               offsetof(Impl_, type_) +
               sizeof(Impl_::write_mode_));

  // @@protoc_insertion_point(copy_constructor:google.cloud.bigquery.storage.v1.WriteStream)
}
PROTOBUF_NDEBUG_INLINE WriteStream::Impl_::Impl_(
    [[maybe_unused]] ::google::protobuf::internal::InternalVisibility visibility,
    [[maybe_unused]] ::google::protobuf::Arena* PROTOBUF_NULLABLE arena)
      : _cached_size_{0},
        name_(arena),
        location_(arena) {}

inline void WriteStream::SharedCtor(::_pb::Arena* PROTOBUF_NULLABLE arena) {
  new (&_impl_) Impl_(internal_visibility(), arena);
  ::memset(reinterpret_cast<char*>(&_impl_) +
               offsetof(Impl_, create_time_),
           0,
           offsetof(Impl_, write_mode_) -
               offsetof(Impl_, create_time_) +
               sizeof(Impl_::write_mode_));
}
WriteStream::~WriteStream() {
  // @@protoc_insertion_point(destructor:google.cloud.bigquery.storage.v1.WriteStream)
  SharedDtor(*this);
}
inline void WriteStream::SharedDtor(MessageLite& self) {
  WriteStream& this_ = static_cast<WriteStream&>(self);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  this_._internal_metadata_.Delete<::google::protobuf::UnknownFieldSet>();
  ABSL_DCHECK(this_.GetArena() == nullptr);
  this_._impl_.name_.Destroy();
  this_._impl_.location_.Destroy();
  delete this_._impl_.create_time_;
  delete this_._impl_.commit_time_;
  delete this_._impl_.table_schema_;
  this_._impl_.~Impl_();
}

#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const
    ::google::protobuf::internal::ClassDataFull WriteStream_class_data_ =
        WriteStream::InternalGenerateClassData_(WriteStream_globals_._default);

PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
WriteStream::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&WriteStream_class_data_);
  ::google::protobuf::internal::PrefetchToLocalCache(WriteStream_class_data_.tc_table);
  return WriteStream_class_data_.base();
}
#else
PROTOBUF_ATTRIBUTE_WEAK const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
WriteStream::GetClassData() const {
  ::google::protobuf::internal::PrefetchToLocalCache(&WriteStream_globals_);
  ::google::protobuf::internal::PrefetchToLocalCache(
      ::google::protobuf::internal::MessageGlobalsBase::ToParseTableBase(&WriteStream_globals_));
  return WriteStream_globals_.GetClassData();
}
#endif  // !PROTOBUF_MESSAGE_GLOBALS
#ifndef PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_CONSTINIT
PROTOBUF_ATTRIBUTE_INIT_PRIORITY1 const WriteStream::ParseTableT_
    WriteStream::_table_ =
        WriteStream::InternalGenerateParseTable_(WriteStream_class_data_.base());
#endif  // !PROTOBUF_MESSAGE_GLOBALS
PROTOBUF_NOINLINE void WriteStream::Clear() {
// @@protoc_insertion_point(message_clear_start:google.cloud.bigquery.storage.v1.WriteStream)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void) cached_has_bits;

  cached_has_bits = _impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000001fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      _impl_.name_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      _impl_.location_.ClearNonDefaultToEmpty();
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(_impl_.create_time_ != nullptr);
      _impl_.create_time_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      ABSL_DCHECK(_impl_.commit_time_ != nullptr);
      _impl_.commit_time_->Clear();
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      ABSL_DCHECK(_impl_.table_schema_ != nullptr);
      _impl_.table_schema_->Clear();
    }
  }
  if (BatchCheckHasBit(cached_has_bits, 0x00000060U)) {
    ::memset(&_impl_.type_, 0, static_cast<::size_t>(
        reinterpret_cast<char*>(&_impl_.write_mode_) -
        reinterpret_cast<char*>(&_impl_.type_)) + sizeof(_impl_.write_mode_));
  }
  _impl_._has_bits_.Clear();
  _internal_metadata_.Clear<::google::protobuf::UnknownFieldSet>();
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::uint8_t* PROTOBUF_NONNULL WriteStream::_InternalSerialize(
    const ::google::protobuf::MessageLite& base, ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) {
  const WriteStream& this_ = static_cast<const WriteStream&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::uint8_t* PROTOBUF_NONNULL WriteStream::_InternalSerialize(
    ::uint8_t* PROTOBUF_NONNULL target,
    ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
  const WriteStream& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    this_.CheckHasBitConsistency();
  }
  // @@protoc_insertion_point(serialize_to_array_start:google.cloud.bigquery.storage.v1.WriteStream)
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = this_._impl_._has_bits_[0];
  // string name = 1 [(.google.api.field_behavior) = OUTPUT_ONLY];
  if (CheckHasBit(cached_has_bits, 0x00000001U)) {
    if (!this_._internal_name().empty()) {
      const ::std::string& _s = this_._internal_name();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "google.cloud.bigquery.storage.v1.WriteStream.name");
      target = stream->WriteStringMaybeAliased(1, _s, target);
    }
  }

  // .google.cloud.bigquery.storage.v1.WriteStream.Type type = 2 [(.google.api.field_behavior) = IMMUTABLE];
  if (CheckHasBit(cached_has_bits, 0x00000020U)) {
    if (this_._internal_type() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteEnumToArray(
          2, this_._internal_type(), target);
    }
  }

  // .google.protobuf.Timestamp create_time = 3 [(.google.api.field_behavior) = OUTPUT_ONLY];
  if (CheckHasBit(cached_has_bits, 0x00000004U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        3, *this_._impl_.create_time_, this_._impl_.create_time_->GetCachedSize(), target,
        stream);
  }

  // .google.protobuf.Timestamp commit_time = 4 [(.google.api.field_behavior) = OUTPUT_ONLY];
  if (CheckHasBit(cached_has_bits, 0x00000008U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        4, *this_._impl_.commit_time_, this_._impl_.commit_time_->GetCachedSize(), target,
        stream);
  }

  // .google.cloud.bigquery.storage.v1.TableSchema table_schema = 5 [(.google.api.field_behavior) = OUTPUT_ONLY];
  if (CheckHasBit(cached_has_bits, 0x00000010U)) {
    target = ::google::protobuf::internal::WireFormatLite::InternalWriteMessage(
        5, *this_._impl_.table_schema_, this_._impl_.table_schema_->GetCachedSize(), target,
        stream);
  }

  // .google.cloud.bigquery.storage.v1.WriteStream.WriteMode write_mode = 7 [(.google.api.field_behavior) = IMMUTABLE];
  if (CheckHasBit(cached_has_bits, 0x00000040U)) {
    if (this_._internal_write_mode() != 0) {
      target = stream->EnsureSpace(target);
      target = ::_pbi::WireFormatLite::WriteEnumToArray(
          7, this_._internal_write_mode(), target);
    }
  }

  // string location = 8 [(.google.api.field_behavior) = IMMUTABLE];
  if (CheckHasBit(cached_has_bits, 0x00000002U)) {
    if (!this_._internal_location().empty()) {
      const ::std::string& _s = this_._internal_location();
      ::google::protobuf::internal::WireFormatLite::VerifyUtf8String(
          _s.data(), static_cast<int>(_s.length()), ::google::protobuf::internal::WireFormatLite::SERIALIZE, "google.cloud.bigquery.storage.v1.WriteStream.location");
      target = stream->WriteStringMaybeAliased(8, _s, target);
    }
  }

  if (ABSL_PREDICT_FALSE(this_._internal_metadata_.have_unknown_fields())) {
    target =
        ::_pbi::WireFormat::InternalSerializeUnknownFieldsToArray(
            this_._internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance), target, stream);
  }
  // @@protoc_insertion_point(serialize_to_array_end:google.cloud.bigquery.storage.v1.WriteStream)
  return target;
}

#if defined(PROTOBUF_CUSTOM_VTABLE)
::size_t WriteStream::ByteSizeLong(const MessageLite& base) {
  const WriteStream& this_ = static_cast<const WriteStream&>(base);
#else   // PROTOBUF_CUSTOM_VTABLE
::size_t WriteStream::ByteSizeLong() const {
  const WriteStream& this_ = *this;
#endif  // PROTOBUF_CUSTOM_VTABLE
  // @@protoc_insertion_point(message_byte_size_start:google.cloud.bigquery.storage.v1.WriteStream)
  ::size_t total_size = 0;

  ::uint32_t cached_has_bits = 0;
  // Prevent compiler warnings about cached_has_bits being unused
  (void)cached_has_bits;

  ::_pbi::Prefetch5LinesFrom7Lines(&this_);
  cached_has_bits = this_._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000007fU)) {
    // string name = 1 [(.google.api.field_behavior) = OUTPUT_ONLY];
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!this_._internal_name().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_name());
      }
    }
    // string location = 8 [(.google.api.field_behavior) = IMMUTABLE];
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!this_._internal_location().empty()) {
        total_size += 1 + ::google::protobuf::internal::WireFormatLite::StringSize(
                                        this_._internal_location());
      }
    }
    // .google.protobuf.Timestamp create_time = 3 [(.google.api.field_behavior) = OUTPUT_ONLY];
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.create_time_);
    }
    // .google.protobuf.Timestamp commit_time = 4 [(.google.api.field_behavior) = OUTPUT_ONLY];
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.commit_time_);
    }
    // .google.cloud.bigquery.storage.v1.TableSchema table_schema = 5 [(.google.api.field_behavior) = OUTPUT_ONLY];
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      total_size += 1 +
                    ::google::protobuf::internal::WireFormatLite::MessageSize(*this_._impl_.table_schema_);
    }
    // .google.cloud.bigquery.storage.v1.WriteStream.Type type = 2 [(.google.api.field_behavior) = IMMUTABLE];
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (this_._internal_type() != 0) {
        total_size += 1 +
                      ::_pbi::WireFormatLite::EnumSize(this_._internal_type());
      }
    }
    // .google.cloud.bigquery.storage.v1.WriteStream.WriteMode write_mode = 7 [(.google.api.field_behavior) = IMMUTABLE];
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (this_._internal_write_mode() != 0) {
        total_size += 1 +
                      ::_pbi::WireFormatLite::EnumSize(this_._internal_write_mode());
      }
    }
  }
  return this_.MaybeComputeUnknownFieldsSize(total_size,
                                             &this_._impl_._cached_size_);
}

void WriteStream::MergeImpl(::google::protobuf::MessageLite& to_msg,
                      const ::google::protobuf::MessageLite& from_msg) {
   auto* const _this = static_cast<WriteStream*>(&to_msg);
  auto& from = static_cast<const WriteStream&>(from_msg);
  if constexpr (::_pbi::DebugHardenCheckHasBitConsistency()) {
    from.CheckHasBitConsistency();
  }
  ::google::protobuf::Arena* arena = _this->GetArena();
  // @@protoc_insertion_point(class_specific_merge_from_start:google.cloud.bigquery.storage.v1.WriteStream)
  ABSL_DCHECK_NE(&from, _this);
  ::uint32_t cached_has_bits = 0;
  (void)cached_has_bits;

  cached_has_bits = from._impl_._has_bits_[0];
  if (BatchCheckHasBit(cached_has_bits, 0x0000007fU)) {
    if (CheckHasBit(cached_has_bits, 0x00000001U)) {
      if (!from._internal_name().empty()) {
        _this->_internal_set_name(from._internal_name());
      } else {
        if (_this->_impl_.name_.IsDefault()) {
          _this->_internal_set_name("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000002U)) {
      if (!from._internal_location().empty()) {
        _this->_internal_set_location(from._internal_location());
      } else {
        if (_this->_impl_.location_.IsDefault()) {
          _this->_internal_set_location("");
        }
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000004U)) {
      ABSL_DCHECK(from._impl_.create_time_ != nullptr);
      if (_this->_impl_.create_time_ == nullptr) {
        _this->_impl_.create_time_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.create_time_);
      } else {
        _this->_impl_.create_time_->MergeFrom(*from._impl_.create_time_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000008U)) {
      ABSL_DCHECK(from._impl_.commit_time_ != nullptr);
      if (_this->_impl_.commit_time_ == nullptr) {
        _this->_impl_.commit_time_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.commit_time_);
      } else {
        _this->_impl_.commit_time_->MergeFrom(*from._impl_.commit_time_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000010U)) {
      ABSL_DCHECK(from._impl_.table_schema_ != nullptr);
      if (_this->_impl_.table_schema_ == nullptr) {
        _this->_impl_.table_schema_ = ::google::protobuf::Message::CopyConstruct(arena, *from._impl_.table_schema_);
      } else {
        _this->_impl_.table_schema_->MergeFrom(*from._impl_.table_schema_);
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000020U)) {
      if (from._internal_type() != 0) {
        _this->_impl_.type_ = from._impl_.type_;
      }
    }
    if (CheckHasBit(cached_has_bits, 0x00000040U)) {
      if (from._internal_write_mode() != 0) {
        _this->_impl_.write_mode_ = from._impl_.write_mode_;
      }
    }
  }
  _this->_impl_._has_bits_[0] |= cached_has_bits;
  _this->_internal_metadata_.MergeFrom<::google::protobuf::UnknownFieldSet>(
      from._internal_metadata_);
}

void WriteStream::CopyFrom(const WriteStream& from) {
  // @@protoc_insertion_point(class_specific_copy_from_start:google.cloud.bigquery.storage.v1.WriteStream)
  if (&from == this) return;
  Clear();
  MergeFrom(from);
}


void WriteStream::InternalSwap(WriteStream* PROTOBUF_RESTRICT PROTOBUF_NONNULL other) {
  using ::std::swap;
  auto* arena = GetArena();
  ABSL_DCHECK_EQ(arena, other->GetArena());
  _internal_metadata_.InternalSwap(&other->_internal_metadata_);
  swap(_impl_._has_bits_[0], other->_impl_._has_bits_[0]);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.name_, &other->_impl_.name_, arena);
  ::_pbi::ArenaStringPtr::InternalSwap(&_impl_.location_, &other->_impl_.location_, arena);
  ::google::protobuf::internal::memswap<
      PROTOBUF_FIELD_OFFSET(WriteStream, _impl_.write_mode_)
      + sizeof(WriteStream::_impl_.write_mode_)
      - PROTOBUF_FIELD_OFFSET(WriteStream, _impl_.create_time_)>(
          reinterpret_cast<char*>(&_impl_.create_time_),
          reinterpret_cast<char*>(&other->_impl_.create_time_));
}

::google::protobuf::Metadata WriteStream::GetMetadata() const {
  return ::google::protobuf::Message::GetMetadataImpl(GetClassData()->full());
}
// @@protoc_insertion_point(namespace_scope)
}  // namespace v1
}  // namespace storage
}  // namespace bigquery
}  // namespace cloud
}  // namespace google
namespace google {
namespace protobuf {
}  // namespace protobuf
}  // namespace google
// @@protoc_insertion_point(global_scope)
PROTOBUF_ATTRIBUTE_INIT_PRIORITY2 static ::std::false_type
    _static_init2_ [[maybe_unused]] =
        (::_pbi::AddDescriptors(&descriptor_table_google_2fcloud_2fbigquery_2fstorage_2fv1_2fstream_2eproto),
         ::std::false_type{});
#include "google/protobuf/port_undef.inc"
